1. Time Travel | 24.118x Courseware | edX

Skip to main content
Help

## edX Help

For questions on course lectures, homework, tools, or materials for this course, post in the course discussion forum.

Have general questions about edX? You can find lots of helpful information in the edX FAQ.

Have a question about something specific? You can contact the edX general support team directly:

Report a problem Make a suggestion Ask a question

Please note: The edX support team is English speaking. While we will do our best to address your inquiry in any language, our responses will be in English.

Briefly describe your issue* Tell us the details* Include error messages, steps which lead to the issue, etc

## Thank You!

Thank you for your inquiry or feedback. We typically respond to a request within one business day (Monday to Friday, 13:00 UTC to 21:00 UTC.) In the meantime, please review our detailed FAQs where most questions have already been answered.

<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-usage-id="block-v1:MITx+24.118x+2T2015+type@vertical+block@24658f8298894eb7ab327e5c6a83b39a" data-block-type="vertical" data-course-id="course-v1:MITx+24.118x+2T2015"> <div class="vert-mod"> <div class="vert vert-0" data-id="block-v1:MITx+24.118x+2T2015+type@video+block@b1588e7cccff4d448f4f9676c81184d9"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@video+block@b1588e7cccff4d448f4f9676c81184d9" data-type="Video" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>Video: Welcome to Week 1!</h2> <div id="video_b1588e7cccff4d448f4f9676c81184d9" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "MIT24118T314-V015000_DTH", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@b1588e7cccff4d448f4f9676c81184d9/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/mit-24118/MIT24118T314-V015000_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:rjOpZ3i6pRo", "saveStateUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@b1588e7cccff4d448f4f9676c81184d9/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@b1588e7cccff4d448f4f9676c81184d9/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_b1588e7cccff4d448f4f9676c81184d9" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="b1588e7cccff4d448f4f9676c81184d9"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_b1588e7cccff4d448f4f9676c81184d9" href="#after-transcript_b1588e7cccff4d448f4f9676c81184d9">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_b1588e7cccff4d448f4f9676c81184d9" href="#before-transcript_b1588e7cccff4d448f4f9676c81184d9">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/mit-24118/MIT24118T314-V015000_DTH.mp4">Download video</a> </li> </ul> </div> </div> </div> <div class="vert vert-1" data-id="block-v1:MITx+24.118x+2T2015+type@html+block@54ea7571d2ad42c398025028b413836f"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@html+block@54ea7571d2ad42c398025028b413836f" data-type="HTMLModule" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <p>[<span style="font-family: 'book antiqua', palatino;">See&nbsp;<a href="https://www.youtube.com/watch?v=5OXQypOAbdI" target="[object Object]">here</a> for Tina Fey&rsquo;s take on the Time Traveler&rsquo;s Convention.]</span></p> </div> </div> </div> </div>
<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-usage-id="block-v1:MITx+24.118x+2T2015+type@vertical+block@86a3c0e24a324cea807f474ba10924e2" data-block-type="vertical" data-course-id="course-v1:MITx+24.118x+2T2015"> <div class="vert-mod"> <div class="vert vert-0" data-id="block-v1:MITx+24.118x+2T2015+type@html+block@413faf18386742f3b90a32ec9f7d9e17"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@html+block@413faf18386742f3b90a32ec9f7d9e17" data-type="HTMLModule" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h3>Consistent and Inconsistent Time Travel Stories</h3> <p></p> <p style="font-size: 16px; font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif; margin: 20px 0px 1.41575em;"><span style="font-size: 1em; line-height: 1.4em; font-family: 'book antiqua', palatino; color: #2e2d29;"><em style="line-height: 1.4em;"><a href="https://www.youtube.com/watch?v=yosuvf7Unmg" target="_blank" style="font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif; font-style: normal; font-size: 1em; line-height: 1.4em; text-decoration: none; -webkit-transition: all 0.1s linear 0s; transition: all 0.1s linear 0s;"><i>Back to the Future</i></a></em>&nbsp;is an inconsistent time travel story. </span></p> <p style="font-size: 16px; font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif; margin: 20px 0px 1.41575em;"><span style="font-family: book antiqua,palatino;">At the beginning of the film we are told that, on October 25, 1985, George McFly is respected by none, and leads a miserable life. Later in the film we are told that George&rsquo;s son, Marty, travels back in time to 1955 and meets his young father. As a result of their meeting, George conquers his fears, and blossoms into a bold and courageous man. Towards the end of the film, we are told that Marty returns to October 25, 1985, and is faced with a very different situation from the one that was described at the beginning of the film. George is respected by all, and leads a happy life.</span></p> <p style="font-size: 16px; font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif; margin-right: 0px; margin-bottom: 1.41575em; margin-left: 0px;"><span style="font-size: 1em; line-height: 1.4em; font-family: book antiqua,palatino; color: #2e2d29;">It is not hard to see why this story is inconsistent. At the beginning of the film we are told that George has a miserable life at time \(t\). At the end of the film we are told that George has a happy (and therefore non-miserable) life at time \(t\). In other words: what we are told at the beginning of the film conflicts with what we are told at the end of the film.&nbsp;</span></p> <p style="font-size: 16px; font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif; margin-right: 0px; margin-bottom: 1.41575em; margin-left: 0px;"><span style="font-size: 1em; line-height: 1.4em; font-family: book antiqua,palatino; color: #2e2d29;">For a time-travel story to be consistent, it must never give us conflicting descriptions of a single point in the narrative&rsquo;s timeline. If at some point in the story we are told that, on October 25, 1985, the world is thus and so, then this is a fact that must be respected throughout the narrative, regardless of what happens to the characters in the story as they travel through time.</span></p> </div> </div> <div class="vert vert-1" data-id="block-v1:MITx+24.118x+2T2015+type@video+block@2d5cf2fc365a47818f36affca45e41e0"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@video+block@2d5cf2fc365a47818f36affca45e41e0" data-type="Video" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>Question: Couldn't the Timeline change?</h2> <div id="video_2d5cf2fc365a47818f36affca45e41e0" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "MIT24118T314-V000500_DTH", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@2d5cf2fc365a47818f36affca45e41e0/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/mit-24118/MIT24118T314-V000500_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:mboSkFdzcbo", "saveStateUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@2d5cf2fc365a47818f36affca45e41e0/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@2d5cf2fc365a47818f36affca45e41e0/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_2d5cf2fc365a47818f36affca45e41e0" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="2d5cf2fc365a47818f36affca45e41e0"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_2d5cf2fc365a47818f36affca45e41e0" href="#after-transcript_2d5cf2fc365a47818f36affca45e41e0">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_2d5cf2fc365a47818f36affca45e41e0" href="#before-transcript_2d5cf2fc365a47818f36affca45e41e0">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> </ul> </div> </div> </div> <div class="vert vert-2" data-id="block-v1:MITx+24.118x+2T2015+type@html+block@082d1a3f02ba4f4f886db95c47b9888a"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@html+block@082d1a3f02ba4f4f886db95c47b9888a" data-type="HTMLModule" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h3>A World-Travel Interpretation?</h3> <p style="font-size: 16px; font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif; margin-right: 0px; margin-bottom: 1.41575em; margin-left: 0px;"></p> <p style="font-size: 16px; font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif; margin-right: 0px; margin-bottom: 1.41575em; margin-left: 0px;"><span style="font-size: 1em; line-height: 1.4em; font-family: book antiqua,palatino; color: #2e2d29;">We could try to make the story consistent by thinking of it as a story about travelling between worlds, rather than a story of time travel within a single world. The idea is that, when Marty reaches 88 miles per hour in the DeLorean, he travels to the 1955 of a different universe, and then comes back to the 1985 of that other universe. So George is miserable in 1985 in the original universe, and his alternative-universe counterpart is happy in his own, other-worldly 1985. Then there would then be no inconsistency.</span></p> <p style="font-size: 16px; font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif; margin-right: 0px; margin-bottom: 1.41575em; margin-left: 0px;"><span style="font-size: 1em; line-height: 1.4em; font-family: book antiqua,palatino; color: #2e2d29;">But if that is really what happened, then it seems like we should feel very differently about events in the film than the film itself encourages us to feel. For instance, it seems like the film is supposed to have a happy ending. But on the alternate-universe interpretation, the ending is tragic. At the end, Marty goes to the 1985 of the alternate universe. He seems to think he&rsquo;s been reunited with his real family, and is happy to be home. But he hasn&rsquo;t; he&rsquo;s meeting these alternate-universe copies of his real family for the first time. His real family is still miserable back in his home universe. They are probably even more miserable now that Marty has disappeared. It seems that Marty will live out his days as an impostor in this new universe, his old universe abandoned. This makes&nbsp;<em style="line-height: 1.4em;">Back to the Future</em>&nbsp;a total downer!</span></p> </div> </div> <div class="vert vert-3" data-id="block-v1:MITx+24.118x+2T2015+type@html+block@bdede4ef5eb94a1fa84aa0eb9822933c"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@html+block@bdede4ef5eb94a1fa84aa0eb9822933c" data-type="HTMLModule" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h3>The Moral</h3> <p style="font-size: 16px; font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif; margin-right: 0px; margin-bottom: 1.41575em; margin-left: 0px;"></p> <p style="font-size: 16px; font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif; margin-right: 0px; margin-bottom: 1.41575em; margin-left: 0px;"><span style="font-size: 1em; line-height: 1.4em; font-family: book antiqua,palatino; color: #2e2d29;">The one-universe interpretation of&nbsp;<em style="line-height: 1.4em;">Back to the Future</em>&nbsp;is inconsistent. You might be tempted to think that&nbsp;<em style="line-height: 1.4em;">all&nbsp;</em>time travel stories set in a single universe are inconsistent.&nbsp;Not so!&nbsp;But it takes some ingenuity to make a time travel story completely consistent. That&rsquo;s why consistent time travel stories can be fun to watch. Good examples include&nbsp;<em style="line-height: 1.4em;"><a href="https://www.youtube.com/watch?v=CBNMEwNx9x4" target="_blank" style="font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif; font-style: normal; font-size: 1em; line-height: 1.4em; text-decoration: none; -webkit-transition: all 0.1s linear 0s; transition: all 0.1s linear 0s;">Twelve Monkeys</a></em>&nbsp;and&nbsp;<em style="line-height: 1.4em;"><a href="https://www.youtube.com/watch?v=USUDlMBR-dQ" target="_blank" style="font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif; font-style: normal; font-size: 1em; line-height: 1.4em; text-decoration: none; -webkit-transition: all 0.1s linear 0s; transition: all 0.1s linear 0s;">The Time Traveler&rsquo;s Wife</a></em>. (And maybe&nbsp;<em style="line-height: 1.4em;"><a href="https://www.youtube.com/watch?v=4CC60HJvZRE" target="_blank" style="font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif; font-style: normal; font-size: 1em; line-height: 1.4em; text-decoration: none; -webkit-transition: all 0.1s linear 0s; transition: all 0.1s linear 0s;">Primer</a></em>, though it is so complicated it is hard to tell whether it is consistent or not. Check it out and try to decide!)&nbsp;</span></p> <p style="font-size: 16px; font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif; margin-right: 0px; margin-bottom: 1.41575em; margin-left: 0px;"><span style="font-size: 1em; line-height: 1.4em; font-family: book antiqua,palatino; color: #2e2d29;">Even if not all time-travel stories are inconsistent, the fact that&nbsp;<em>some</em> of them are leads some people to think that time-travel is logically impossible. Read on&hellip;</span></p> </div> </div> <div class="vert vert-4" data-id="block-v1:MITx+24.118x+2T2015+type@video+block@21958d8092d14e44aeac253c41ac1ca7"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@video+block@21958d8092d14e44aeac253c41ac1ca7" data-type="Video" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>Video Review: Consistent and Inconsistent Time Travel Stories</h2> <div id="video_21958d8092d14e44aeac253c41ac1ca7" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "MIT24118T314-V000300_DTH", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@21958d8092d14e44aeac253c41ac1ca7/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/mit-24118/MIT24118T314-V000300_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:-NvRCu3EDVE", "saveStateUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@21958d8092d14e44aeac253c41ac1ca7/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@21958d8092d14e44aeac253c41ac1ca7/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_21958d8092d14e44aeac253c41ac1ca7" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="21958d8092d14e44aeac253c41ac1ca7"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_21958d8092d14e44aeac253c41ac1ca7" href="#after-transcript_21958d8092d14e44aeac253c41ac1ca7">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_21958d8092d14e44aeac253c41ac1ca7" href="#before-transcript_21958d8092d14e44aeac253c41ac1ca7">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/mit-24118/MIT24118T314-V000300_DTH.mp4">Download video</a> </li> </ul> </div> </div> </div> <div class="vert vert-5" data-id="block-v1:MITx+24.118x+2T2015+type@problem+block@003aa01cda12459f9ec48b1b1ca66e01"> <div class="xblock xblock-student_view xblock-student_view-problem xmodule_display xmodule_CapaModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="problem" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@problem+block@003aa01cda12459f9ec48b1b1ca66e01" data-type="Problem" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Problem"} </script> <div id="problem_003aa01cda12459f9ec48b1b1ca66e01" class="problems-wrapper" data-problem-id="block-v1:MITx+24.118x+2T2015+type@problem+block@003aa01cda12459f9ec48b1b1ca66e01" data-url="/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@problem+block@003aa01cda12459f9ec48b1b1ca66e01/handler/xmodule_handler" data-progress_status="0" data-progress_detail="0"></div> </div> </div> <div class="vert vert-6" data-id="block-v1:MITx+24.118x+2T2015+type@problem+block@911d1b57c8984817b6f8f68e7ac96f91"> <div class="xblock xblock-student_view xblock-student_view-problem xmodule_display xmodule_CapaModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="problem" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@problem+block@911d1b57c8984817b6f8f68e7ac96f91" data-type="Problem" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Problem"} </script> <div id="problem_911d1b57c8984817b6f8f68e7ac96f91" class="problems-wrapper" data-problem-id="block-v1:MITx+24.118x+2T2015+type@problem+block@911d1b57c8984817b6f8f68e7ac96f91" data-url="/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@problem+block@911d1b57c8984817b6f8f68e7ac96f91/handler/xmodule_handler" data-progress_status="0" data-progress_detail="0"></div> </div> </div> <div class="vert vert-7" data-id="block-v1:MITx+24.118x+2T2015+type@problem+block@0cbcc8471df245dd82484d445c4cf515"> <div class="xblock xblock-student_view xblock-student_view-problem xmodule_display xmodule_CapaModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="problem" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@problem+block@0cbcc8471df245dd82484d445c4cf515" data-type="Problem" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Problem"} </script> <div id="problem_0cbcc8471df245dd82484d445c4cf515" class="problems-wrapper" data-problem-id="block-v1:MITx+24.118x+2T2015+type@problem+block@0cbcc8471df245dd82484d445c4cf515" data-url="/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@problem+block@0cbcc8471df245dd82484d445c4cf515/handler/xmodule_handler" data-progress_status="0" data-progress_detail="0"></div> </div> </div> <div class="vert vert-8" data-id="block-v1:MITx+24.118x+2T2015+type@html+block@f17f2f90149c47c1a846142f7e41f8ad"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@html+block@f17f2f90149c47c1a846142f7e41f8ad" data-type="HTMLModule" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h3 style="color: #2e2d29; line-height: 1.4em; font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif;">Optional Activities</h3> <ul style="line-height: 22.399999618530273px; font-family: 'Source Sans', 'Open Sans', Verdana, Geneva, sans-serif, sans-serif;"> <li><span style="font-size: 1em; line-height: 1.6em; color: #2e2d29;">Watch&nbsp;</span><i style="line-height: 1.6em; font-size: 1em;">Twelve Monkeys</i><span style="font-size: 1em; line-height: 1.6em; color: #2e2d29;">, and think about how to interpret it as a consistent time travel story.</span></li> <li><b style="line-height: 1.6em; font-size: 1em;">Advanced Option:<i style="line-height: 1.4em;">&nbsp;</i></b><span style="font-size: 1em; line-height: 1.6em; color: #2e2d29;">Watch&nbsp;</span><i style="line-height: 1.6em; font-size: 1em;">Primer</i><span style="font-size: 1em; line-height: 1.6em; color: #2e2d29;">&nbsp;and determine whether it can be interpreted as a consistent time travel story or not.</span></li> </ul> </div> </div> <div class="vert vert-9" data-id="block-v1:MITx+24.118x+2T2015+type@discussion+block@f355bf36233c40a18b72b66e4fc530b7"> <div class="xblock xblock-student_view xblock-student_view-discussion xmodule_display xmodule_DiscussionModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="discussion" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@discussion+block@f355bf36233c40a18b72b66e4fc530b7" data-type="InlineDiscussion" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "InlineDiscussion"} </script> <script aria-hidden="true" type="text/template" id="thread-template"> <article class="discussion-article" data-id="<%- id %>"> <div class="thread-wrapper" tabindex="-1"> <div class="forum-thread-main-wrapper"> <div class="thread-content-wrapper"></div> <div class="post-extended-content"> <ol class="responses js-marked-answer-list"></ol> </div> </div> <div class="post-extended-content"> <div class="response-count"/> <div class="add-response"> <button class="button add-response-btn"> <i class="icon fa fa-reply"></i> <span class="add-response-btn-text">Add A Response</span> </button> </div> <ol class="responses js-response-list"/> <div class="response-pagination"/> <div class="post-status-closed bottom-post-status" style="display: none"> This thread is closed. </div> <form class="discussion-reply-new" data-id="<%- id %>"> <h4>Post a response:</h4> <ul class="discussion-errors"></ul> <div class="reply-body" data-id="<%- id %>"></div> <div class="reply-post-control"> <a class="discussion-submit-post control-button" href="#">Submit</a> </div> </form> </div> </div> <div class="post-tools"> <a href="javascript:void(0)" class="forum-thread-expand"><span class="icon fa fa-plus"/> Expand discussion</a> <a href="javascript:void(0)" class="forum-thread-collapse"><span class="icon fa fa-minus"/> Collapse discussion</a> </div> </article> </script> <script aria-hidden="true" type="text/template" id="thread-show-template"> <div class="discussion-post"> <header> <div class="group-visibility-label"> <% if (obj.group_name) { %> <%- interpolate( gettext('This post is visible only to %(group_name)s.'), {group_name: obj.group_name}, true ) %> <% } else { %> <%- gettext('This post is visible to everyone.') %> <% } %> </div> <div class="post-header-content"> <h1><%- title %></h1> <p class="posted-details"> <% var timeAgoHtml = interpolate( '<span class="timeago" title="%(created_at)s">%(created_at)s</span>', {created_at: created_at}, true ); %> <%= interpolate( // Translators: post_type describes the kind of post this is (e.g. "question" or "discussion"); // time_ago is how much time has passed since the post was created (e.g. "4 hours ago") _.escape(gettext('%(post_type)s posted %(time_ago)s by %(author)s')), {post_type: thread_type, time_ago: timeAgoHtml, author: author_display}, true ) %> </p> <div class="post-labels"> <span class="post-label-pinned"><i class="icon fa fa-thumb-tack"></i><%- gettext("Pinned") %></span> <span class="post-label-reported"><i class="icon fa fa-flag"></i><%- gettext("Reported") %></span> <span class="post-label-closed"><i class="icon fa fa-lock"></i><%- gettext("Closed") %></span> </div> </div> <div class="post-header-actions post-extended-content"> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'post', primaryActions: ['vote', 'follow'], secondaryActions: ['pin', 'edit', 'delete', 'report', 'close'] } ) %> </div> </header> <div class="post-body"><%- body %></div> <% if (mode == "tab" && obj.courseware_url) { %> <% var courseware_title_linked = interpolate( '<a href="%(courseware_url)s">%(courseware_title)s</a>', {courseware_url: courseware_url, courseware_title: _.escape(courseware_title)}, true ); %> <div class="post-context"> <%= interpolate( _.escape(gettext('Related to: %(courseware_title_linked)s')), {courseware_title_linked: courseware_title_linked}, true ) %> </div> <% } %> </div> </script> <script aria-hidden="true" type="text/template" id="thread-edit-template"> <h1>Editing post</h1> <ul class="post-errors"></ul> <div class="forum-edit-post-form-wrapper"></div> <div class="form-row"> <label class="sr" for="edit-post-title">Edit post title</label> <input type="text" id="edit-post-title" class="edit-post-title" name="title" value="<%-title %>" placeholder="Title"> </div> <div class="form-row"> <div class="edit-post-body" name="body"><%- body %></div> </div> <input type="submit" id="edit-post-submit" class="post-update" value="Update post"> <a href="#" class="post-cancel">Cancel</a> </script> <script aria-hidden="true" type="text/template" id="thread-response-template"> <div class="discussion-response"></div> <a href="#" class="action-show-comments"> <%- interpolate('Show Comments (%(num_comments)s)', {num_comments: comments.length}, true) %> <i class="icon fa fa-caret-down"></i> </a> <ol class="comments"> <li class="new-comment"> <form class="comment-form" data-id="<%- wmdId %>"> <ul class="discussion-errors"></ul> <label class="sr" for="add-new-comment">Add a comment</label> <div class="comment-body" id="add-new-comment" data-id="<%- wmdId %>" data-placeholder="Add a comment"></div> <div class="comment-post-control"> <a class="discussion-submit-comment control-button" href="#">Submit</a> </div> </form> </li> </ol> </script> <script aria-hidden="true" type="text/template" id="thread-response-show-template"> <header> <div class="response-header-content"> <%= author_display %> <p class="posted-details"> <span class="timeago" title="<%= created_at %>"><%= created_at %></span> <% if (obj.endorsement) { %> - <%= interpolate( thread.get("thread_type") == "question" ? (endorsement.username ? "marked as answer %(time_ago)s by %(user)s" : "marked as answer %(time_ago)s") : (endorsement.username ? "endorsed %(time_ago)s by %(user)s" : "endorsed %(time_ago)s"), { 'time_ago': '<span class="timeago" title="' + endorsement.time + '">' + endorsement.time + '</span>', 'user': endorser_display }, true )%><% } %> </p> <div class="post-labels"> <span class="post-label-reported"><i class="icon fa fa-flag"></i>Reported</span> </div> </div> <div class="response-header-actions"> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'response', primaryActions: ['vote', thread.get('thread_type') == 'question' ? 'answer' : 'endorse'], secondaryActions: ['edit', 'delete', 'report'] } ) %> </div> </header> <div class="response-body"><%- body %></div> </script> <script aria-hidden="true" type="text/template" id="thread-response-edit-template"> <div class="edit-post-form"> <h1>Editing response</h1> <ul class="edit-post-form-errors"></ul> <div class="form-row"> <div class="edit-post-body" name="body" data-id="<%- id %>"><%- body %></div> </div> <input type="submit" id="edit-response-submit"class="post-update" value="Update response"> <a href="#" class="post-cancel">Cancel</a> </div> </script> <script aria-hidden="true" type="text/template" id="response-comment-show-template"> <div id="comment_<%- id %>"> <div class="response-body"><%- body %></div> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'comment', primaryActions: [], secondaryActions: ['edit', 'delete', 'report'] } ) %> <p class="posted-details"> <%= interpolate( 'posted %(time_ago)s by %(author)s', {'time_ago': '<span class="timeago" title="' + created_at + '">' + created_at + '</span>', 'author': author_display}, true )%> </p> <div class="post-labels"> <span class="post-label-reported"><i class="icon fa fa-flag"></i>Reported</span> </div> </div> </script> <script aria-hidden="true" type="text/template" id="response-comment-edit-template"> <div class="edit-post-form" id="comment_<%- id %>"> <h1>Editing comment</h1> <ul class="edit-comment-form-errors"></ul> <div class="form-row"> <div class="edit-comment-body" name="body" data-id="<%- id %>"><%- body %></div> </div> <input type="submit" id="edit-comment-submit" class="post-update" value="Update comment"> <a href="#" class="post-cancel">Cancel</a> </div> </script> <script aria-hidden="true" type="text/template" id="thread-list-item-template"> <li data-id="<%- id %>" class="forum-nav-thread<% if (typeof(read) != "undefined" && !read) { %> is-unread<% } %>"> <a href="#" class="forum-nav-thread-link"> <div class="forum-nav-thread-wrapper-0"> <% var icon_class, sr_text; if (thread_type == "discussion") { icon_class = "fa-comments"; sr_text = "discussion"; } else if (endorsed) { icon_class = "fa-check-square-o"; sr_text = "answered question"; } else { icon_class = "fa-question"; sr_text = "unanswered question"; } %> <span class="sr"><%= sr_text %></span> <i class="icon fa <%= icon_class %>"></i> </div><div class="forum-nav-thread-wrapper-1"> <span class="forum-nav-thread-title"><%- title %></span> <% var labels = ""; if (pinned) { labels += '<li class="post-label-pinned"><i class="icon fa fa-thumb-tack"></i>Pinned</li> '; } if (typeof(subscribed) != "undefined" && subscribed) { labels += '<li class="post-label-following"><i class="icon fa fa-star"></i>Following</li> '; } if (staff_authored) { labels += '<li class="post-label-by-staff"><i class="icon fa fa-user"></i>By: Staff</li> '; } if (community_ta_authored) { labels += '<li class="post-label-by-community-ta"><i class="icon fa fa-user"></i>By: Community TA</li> '; } if (labels != "") { print('<ul class="forum-nav-thread-labels">' + labels + '</ul>'); } %> </div><div class="forum-nav-thread-wrapper-2"> <span class="forum-nav-thread-votes-count">+<%= interpolate( '%(votes_up_count)s%(span_sr_open)s votes %(span_close)s', {'span_sr_open': '<span class="sr">', 'span_close': '</span>', 'votes_up_count': votes['up_count']}, true ) %></span> <span class="forum-nav-thread-comments-count <% if (unread_comments_count > 0) { %>is-unread<% } %>"> <% var fmt; // Counts in data do not include the post itself, but the UI should var data = { 'span_sr_open': '<span class="sr">', 'span_close': '</span>', 'unread_comments_count': unread_comments_count + (read ? 0 : 1), 'comments_count': comments_count + 1 }; if (unread_comments_count > 0) { fmt = '%(comments_count)s %(span_sr_open)scomments (%(unread_comments_count)s unread comments)%(span_close)s'; } else { fmt = '%(comments_count)s %(span_sr_open)scomments %(span_close)s'; } print(interpolate(fmt, data, true)); %> </span> </div> </a> </li> </script> <script aria-hidden="true" type="text/template" id="discussion-home"> <div class="discussion-article blank-slate"> <section class="home-header"> <span class="label">DISCUSSION HOME:</span> <h1 class="home-title">Paradox and Infinity</h1> </section> <span class="label label-settings"> How to use edX discussions </span> <table class="home-helpgrid"> <tr class="helpgrid-row helpgrid-row-navigation"> <td class="row-title">Find discussions</td> <td class="row-item"> <i class="icon fa fa-reorder"></i> <span class="row-description">Focus in on specific topics</span> </td> <td class="row-item"> <i class="icon fa fa-search"></i> <span class="row-description">Search for specific posts </span> </td> <td class="row-item"> <i class="icon fa fa-sort"></i> <span class="row-description">Sort by date, vote, or comments</span> </td> </tr> <tr class="helpgrid-row helpgrid-row-participation"> <td class="row-title">Engage with posts</td> <td class="row-item"> <i class="icon fa fa-plus"></i> <span class="row-description">Upvote posts and good responses</span> </td> <td class="row-item"> <i class="icon fa fa-flag"></i> <span class="row-description">Report Forum Misuse</span> </td> <td class="row-item"> <i class="icon fa fa-star"></i> <span class="row-description">Follow posts for updates</span> </td> </tr> <tr class="helpgrid-row helpgrid-row-notification"> <td class="row-title">Receive updates</td> <td class="row-item-full" colspan="3"> <label for="email-setting-checkbox"> <span class="sr">Toggle Notifications Setting</span> <span class="notification-checkbox"> <input type="checkbox" id="email-setting-checkbox" class="email-setting" name="email-notification"/> <i class="icon fa fa-envelope"></i> </span> </label> <span class="row-description">Check this box to receive an email digest once a day notifying you about new, unread activity from posts you are following.</span> </td> </tr> </table> </div> </script> <script aria-hidden="true" type="text/template" id="search-alert-template"> <div class="search-alert" id="search-alert-<%- cid %>"> <div class="search-alert-content"> <p class="message"><%= message %></p> </div> <div class="search-alert-controls"> <a href="#" class="dismiss control control-dismiss"><i class="icon fa fa-remove"></i></a> </div> </div> </script> <script aria-hidden="true" type="text/template" id="new-post-template"> <form class="forum-new-post-form"> <ul class="post-errors" style="display: none"></ul> <div class="forum-new-post-form-wrapper"></div> <% if (cohort_options) { %> <div class="post-field group-selector-wrapper<% if (!is_commentable_cohorted) { %> disabled<% } %>" > <label class="field-label"> <span class="field-label-text"> Visible To: </span><select aria-describedby="field_help_visible_to" class="field-input js-group-select" name="group_id" <% if (!is_commentable_cohorted) { %>disabled<% } %>> <option value="">All Groups</option> <% _.each(cohort_options, function(opt) { %> <option value="<%= opt.value %>" <% if (opt.selected) { %>selected<% } %>><%- opt.text %></option> <% }); %> </select> </label><div class="field-help" id="field_help_visible_to"> Discussion admins, moderators, and TAs can make their posts visible to all students or specify a single cohort. </div> </div> <% } %> <div class="post-field"> <label class="field-label"> <span class="sr">Title:</span> <input aria-describedby="field_help_title" type="text" class="field-input js-post-title" name="title" placeholder="Title"> </label><span class="field-help" id="field_help_title"> Add a clear and descriptive title to encourage participation. </span> </div> <div class="post-field js-post-body editor" name="body" data-placeholder="Enter your question or comment"></div> <div class="post-options"> <label class="post-option is-enabled"> <input type="checkbox" name="follow" class="post-option-input js-follow" checked> <i class="icon fa fa-star"></i>follow this post </label> <% if (allow_anonymous) { %> <label class="post-option"> <input type="checkbox" name="anonymous" class="post-option-input js-anon"> post anonymously </label> <% } %> <% if (allow_anonymous_to_peers) { %> <label class="post-option"> <input type="checkbox" name="anonymous_to_peers" class="post-option-input js-anon-peers"> post anonymously to classmates </label> <% } %> </div> <div> <input type="submit" class="submit" value="Add Post"> <a href="#" class="cancel">Cancel</a> </div> </form> </script> <script aria-hidden="true" type="text/template" id="thread-type-template"> <div class="post-field"> <div class="field-label"> <span class="field-label-text"> Post type: </span><fieldset class="field-input"><legend class="sr">Post type:</legend> <input aria-describedby="field_help_post_type" type="radio" name="<%= form_id %>-post-type" class="post-type-input" id="<%= form_id %>-post-type-question" value="question"> <label for="<%= form_id %>-post-type-question" class="post-type-label"> <i class="icon fa fa-question"></i> Question </label> <input aria-describedby="field_help_post_type" type="radio" name="<%= form_id %>-post-type" class="post-type-input" id="<%= form_id %>-post-type-discussion" value="discussion" checked> <label for="<%= form_id %>-post-type-discussion" class="post-type-label"> <i class="icon fa fa-comments"></i> Discussion </label> </fieldset> </div><span class="field-help" id="field_help_post_type"> Questions raise issues that need answers. Discussions share ideas and start conversations. </span> </div> </script> <script aria-hidden="true" type="text/template" id="new-post-menu-entry-template"> <li role="menuitem" class="topic-menu-item"> <a href="#" class="topic-title" data-discussion-id="<%- id %>" data-cohorted="<%- is_cohorted %>"><%- text %></a> </li> </script> <script aria-hidden="true" type="text/template" id="new-post-menu-category-template"> <li role="menuitem" class="topic-menu-item"> <span class="topic-title"><%- text %></span> <ul role="menu" class="topic-submenu"><%= entries %></ul> </li> </script> <script aria-hidden="true" type="text/template" id="topic-template"> <div class="field-label"> <span class="field-label-text">Topic Area:</span><div class="field-input post-topic"> <a href="#" class="post-topic-button"> <span class="sr">Discussion topics; current selection is: </span> <span class="js-selected-topic"></span> <span class="drop-arrow" aria-hidden="true">▾</span> </a> <div class="topic-menu-wrapper"> <label class="topic-filter-label"> <span class="sr">Filter topics</span> <input aria-describedby="field_help_topic_area" type="text" class="topic-filter-input" placeholder="Filter topics"> </label> <ul class="topic-menu" role="menu"><%= topics_html %></ul> </div> </div> </div><span class="field-help" id="field_help_topic_area"> Add your post to a relevant topic to help others find it. </span> </script> <script type="text/template" id="forum-action-endorse"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-endorse" role="checkbox" aria-checked="false"> <span class="sr">Endorse</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Endorse</span> <span class="label-checked">Unendorse</span> </span> <span class="action-icon"><i class="icon fa fa-check"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-answer"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-answer" role="checkbox" aria-checked="false"> <span class="sr">Mark as Answer</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Mark as Answer</span> <span class="label-checked">Unmark as Answer</span> </span> <span class="action-icon"><i class="icon fa fa-check"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-follow"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-follow" role="checkbox" aria-checked="false"> <span class="sr">Follow</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Follow</span> <span class="label-checked">Unfollow</span> </span> <span class="action-icon"><i class="icon fa fa-star"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-vote"> <li class="actions-item"> <span aria-hidden="true" class="display-vote" > <span class="vote-count"></span> </span> <a href="#" class="action-button action-vote" role="checkbox" aria-checked="false"> <span class="sr">Vote for this post,&nbsp;</span> <span class="sr js-sr-vote-count"></span> <span class="action-label" aria-hidden="true"> <span class="vote-count"></span> </span> <span class="action-icon" aria-hidden="true"> <i class="icon fa fa-plus"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-report"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-report" role="checkbox" aria-checked="false"> <span class="sr">Report abuse</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Report</span> <span class="label-checked">Unreport</span> </span> <span class="action-icon"> <i class="icon fa fa-flag"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-pin"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-pin" role="checkbox" aria-checked="false"> <span class="sr">Pin</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Pin</span> <span class="label-checked">Unpin</span> </span> <span class="action-icon"> <i class="icon fa fa-thumb-tack"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-close"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-close" role="checkbox" aria-checked="false"> <span class="sr">Close</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Close</span> <span class="label-checked">Open</span> </span> <span class="action-icon"> <i class="icon fa fa-lock"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-edit"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-edit" role="button"> <span class="action-label">Edit</span> <span class="action-icon"><i class="icon fa fa-pencil"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-delete"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-delete" role="button"> <span class="action-label">Delete</span> <span class="action-icon"><i class="icon fa fa-remove"></i></span> </a> </li> </script> <script type="text/template" id="forum-actions"> <ul class="<%= contentType %>-actions-list"> <% _.each(primaryActions, function(action) { print(_.template($('#forum-action-' + action).html(), {})) }) %> <li class="actions-item is-visible"> <div class="more-wrapper"> <a href="javascript:void(0)" class="action-button action-more" role="button" aria-haspopup="true" aria-controls="action-menu-<%= contentId %>"> <span class="action-label">More</span> <span class="action-icon"><i class="icon fa fa-ellipsis-h"></i></span> </a> <div class="actions-dropdown" id="action-menu-<%= contentType %>" aria-expanded="false"> <ul class="actions-dropdown-list"> <% _.each(secondaryActions, function(action) { print(_.template($('#forum-action-' + action).html(), {})) }) %> </ul> </div> </div> </li> </ul> </script> <script aria-hidden="true" type="text/template" id="post-user-display-template"> <% if (username) { %> <a href="<%- user_url %>" class="username"><%- username %></a> <% if (is_community_ta) { %> <span class="user-label-community-ta">Community TA</span> <% } else if (is_staff) { %> <span class="user-label-staff">Staff</span> <% } %> <% } else { %> anonymous <% } %> </script> <div class="discussion-module" data-discussion-id="0919d6f1c1bacea44f49a5d98d873adfe39846c3"> <a class="discussion-show control-button" href="javascript:void(0)" data-discussion-id="0919d6f1c1bacea44f49a5d98d873adfe39846c3" role="button"><span class="show-hide-discussion-icon"></span><span class="button-text">Show Discussion</span></a> <a href="#" class="new-post-btn" role="button"><span class="icon fa fa-edit new-post-icon"></span>New Post</a> </div> </div> </div> </div> </div>
<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-usage-id="block-v1:MITx+24.118x+2T2015+type@vertical+block@3b38b614984d42f4b57f87975cddd13e" data-block-type="vertical" data-course-id="course-v1:MITx+24.118x+2T2015"> <div class="vert-mod"> <div class="vert vert-0" data-id="block-v1:MITx+24.118x+2T2015+type@html+block@212a27d23852410cbf2969d4fb575537"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@html+block@212a27d23852410cbf2969d4fb575537" data-type="HTMLModule" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h3>Self Causation</h3> </div> </div> <div class="vert vert-1" data-id="block-v1:MITx+24.118x+2T2015+type@problem+block@8b4f5433afac4910859b98296ce7b09e"> <div class="xblock xblock-student_view xblock-student_view-problem xmodule_display xmodule_CapaModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="problem" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@problem+block@8b4f5433afac4910859b98296ce7b09e" data-type="Problem" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Problem"} </script> <div id="problem_8b4f5433afac4910859b98296ce7b09e" class="problems-wrapper" data-problem-id="block-v1:MITx+24.118x+2T2015+type@problem+block@8b4f5433afac4910859b98296ce7b09e" data-url="/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@problem+block@8b4f5433afac4910859b98296ce7b09e/handler/xmodule_handler" data-progress_status="0" data-progress_detail="0"></div> </div> </div> <div class="vert vert-2" data-id="block-v1:MITx+24.118x+2T2015+type@video+block@d434ce5eb3504ef2a0d4ffe38c7bf994"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@video+block@d434ce5eb3504ef2a0d4ffe38c7bf994" data-type="Video" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>Question: Isn't that 'Consistent' Case Paradoxical?</h2> <div id="video_d434ce5eb3504ef2a0d4ffe38c7bf994" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "MIT24118T314-V000400_DTH", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@d434ce5eb3504ef2a0d4ffe38c7bf994/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/mit-24118/MIT24118T314-V000400_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:TCAfqOo88Sg", "saveStateUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@d434ce5eb3504ef2a0d4ffe38c7bf994/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@d434ce5eb3504ef2a0d4ffe38c7bf994/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_d434ce5eb3504ef2a0d4ffe38c7bf994" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="d434ce5eb3504ef2a0d4ffe38c7bf994"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_d434ce5eb3504ef2a0d4ffe38c7bf994" href="#after-transcript_d434ce5eb3504ef2a0d4ffe38c7bf994">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_d434ce5eb3504ef2a0d4ffe38c7bf994" href="#before-transcript_d434ce5eb3504ef2a0d4ffe38c7bf994">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/mit-24118/MIT24118T314-V000400_DTH.mp4">Download video</a> </li> </ul> </div> </div> </div> <div class="vert vert-3" data-id="block-v1:MITx+24.118x+2T2015+type@discussion+block@43671c2351cf42d4bfd3b7ba256c9ab6"> <div class="xblock xblock-student_view xblock-student_view-discussion xmodule_display xmodule_DiscussionModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="discussion" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@discussion+block@43671c2351cf42d4bfd3b7ba256c9ab6" data-type="InlineDiscussion" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "InlineDiscussion"} </script> <script aria-hidden="true" type="text/template" id="thread-template"> <article class="discussion-article" data-id="<%- id %>"> <div class="thread-wrapper" tabindex="-1"> <div class="forum-thread-main-wrapper"> <div class="thread-content-wrapper"></div> <div class="post-extended-content"> <ol class="responses js-marked-answer-list"></ol> </div> </div> <div class="post-extended-content"> <div class="response-count"/> <div class="add-response"> <button class="button add-response-btn"> <i class="icon fa fa-reply"></i> <span class="add-response-btn-text">Add A Response</span> </button> </div> <ol class="responses js-response-list"/> <div class="response-pagination"/> <div class="post-status-closed bottom-post-status" style="display: none"> This thread is closed. </div> <form class="discussion-reply-new" data-id="<%- id %>"> <h4>Post a response:</h4> <ul class="discussion-errors"></ul> <div class="reply-body" data-id="<%- id %>"></div> <div class="reply-post-control"> <a class="discussion-submit-post control-button" href="#">Submit</a> </div> </form> </div> </div> <div class="post-tools"> <a href="javascript:void(0)" class="forum-thread-expand"><span class="icon fa fa-plus"/> Expand discussion</a> <a href="javascript:void(0)" class="forum-thread-collapse"><span class="icon fa fa-minus"/> Collapse discussion</a> </div> </article> </script> <script aria-hidden="true" type="text/template" id="thread-show-template"> <div class="discussion-post"> <header> <div class="group-visibility-label"> <% if (obj.group_name) { %> <%- interpolate( gettext('This post is visible only to %(group_name)s.'), {group_name: obj.group_name}, true ) %> <% } else { %> <%- gettext('This post is visible to everyone.') %> <% } %> </div> <div class="post-header-content"> <h1><%- title %></h1> <p class="posted-details"> <% var timeAgoHtml = interpolate( '<span class="timeago" title="%(created_at)s">%(created_at)s</span>', {created_at: created_at}, true ); %> <%= interpolate( // Translators: post_type describes the kind of post this is (e.g. "question" or "discussion"); // time_ago is how much time has passed since the post was created (e.g. "4 hours ago") _.escape(gettext('%(post_type)s posted %(time_ago)s by %(author)s')), {post_type: thread_type, time_ago: timeAgoHtml, author: author_display}, true ) %> </p> <div class="post-labels"> <span class="post-label-pinned"><i class="icon fa fa-thumb-tack"></i><%- gettext("Pinned") %></span> <span class="post-label-reported"><i class="icon fa fa-flag"></i><%- gettext("Reported") %></span> <span class="post-label-closed"><i class="icon fa fa-lock"></i><%- gettext("Closed") %></span> </div> </div> <div class="post-header-actions post-extended-content"> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'post', primaryActions: ['vote', 'follow'], secondaryActions: ['pin', 'edit', 'delete', 'report', 'close'] } ) %> </div> </header> <div class="post-body"><%- body %></div> <% if (mode == "tab" && obj.courseware_url) { %> <% var courseware_title_linked = interpolate( '<a href="%(courseware_url)s">%(courseware_title)s</a>', {courseware_url: courseware_url, courseware_title: _.escape(courseware_title)}, true ); %> <div class="post-context"> <%= interpolate( _.escape(gettext('Related to: %(courseware_title_linked)s')), {courseware_title_linked: courseware_title_linked}, true ) %> </div> <% } %> </div> </script> <script aria-hidden="true" type="text/template" id="thread-edit-template"> <h1>Editing post</h1> <ul class="post-errors"></ul> <div class="forum-edit-post-form-wrapper"></div> <div class="form-row"> <label class="sr" for="edit-post-title">Edit post title</label> <input type="text" id="edit-post-title" class="edit-post-title" name="title" value="<%-title %>" placeholder="Title"> </div> <div class="form-row"> <div class="edit-post-body" name="body"><%- body %></div> </div> <input type="submit" id="edit-post-submit" class="post-update" value="Update post"> <a href="#" class="post-cancel">Cancel</a> </script> <script aria-hidden="true" type="text/template" id="thread-response-template"> <div class="discussion-response"></div> <a href="#" class="action-show-comments"> <%- interpolate('Show Comments (%(num_comments)s)', {num_comments: comments.length}, true) %> <i class="icon fa fa-caret-down"></i> </a> <ol class="comments"> <li class="new-comment"> <form class="comment-form" data-id="<%- wmdId %>"> <ul class="discussion-errors"></ul> <label class="sr" for="add-new-comment">Add a comment</label> <div class="comment-body" id="add-new-comment" data-id="<%- wmdId %>" data-placeholder="Add a comment"></div> <div class="comment-post-control"> <a class="discussion-submit-comment control-button" href="#">Submit</a> </div> </form> </li> </ol> </script> <script aria-hidden="true" type="text/template" id="thread-response-show-template"> <header> <div class="response-header-content"> <%= author_display %> <p class="posted-details"> <span class="timeago" title="<%= created_at %>"><%= created_at %></span> <% if (obj.endorsement) { %> - <%= interpolate( thread.get("thread_type") == "question" ? (endorsement.username ? "marked as answer %(time_ago)s by %(user)s" : "marked as answer %(time_ago)s") : (endorsement.username ? "endorsed %(time_ago)s by %(user)s" : "endorsed %(time_ago)s"), { 'time_ago': '<span class="timeago" title="' + endorsement.time + '">' + endorsement.time + '</span>', 'user': endorser_display }, true )%><% } %> </p> <div class="post-labels"> <span class="post-label-reported"><i class="icon fa fa-flag"></i>Reported</span> </div> </div> <div class="response-header-actions"> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'response', primaryActions: ['vote', thread.get('thread_type') == 'question' ? 'answer' : 'endorse'], secondaryActions: ['edit', 'delete', 'report'] } ) %> </div> </header> <div class="response-body"><%- body %></div> </script> <script aria-hidden="true" type="text/template" id="thread-response-edit-template"> <div class="edit-post-form"> <h1>Editing response</h1> <ul class="edit-post-form-errors"></ul> <div class="form-row"> <div class="edit-post-body" name="body" data-id="<%- id %>"><%- body %></div> </div> <input type="submit" id="edit-response-submit"class="post-update" value="Update response"> <a href="#" class="post-cancel">Cancel</a> </div> </script> <script aria-hidden="true" type="text/template" id="response-comment-show-template"> <div id="comment_<%- id %>"> <div class="response-body"><%- body %></div> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'comment', primaryActions: [], secondaryActions: ['edit', 'delete', 'report'] } ) %> <p class="posted-details"> <%= interpolate( 'posted %(time_ago)s by %(author)s', {'time_ago': '<span class="timeago" title="' + created_at + '">' + created_at + '</span>', 'author': author_display}, true )%> </p> <div class="post-labels"> <span class="post-label-reported"><i class="icon fa fa-flag"></i>Reported</span> </div> </div> </script> <script aria-hidden="true" type="text/template" id="response-comment-edit-template"> <div class="edit-post-form" id="comment_<%- id %>"> <h1>Editing comment</h1> <ul class="edit-comment-form-errors"></ul> <div class="form-row"> <div class="edit-comment-body" name="body" data-id="<%- id %>"><%- body %></div> </div> <input type="submit" id="edit-comment-submit" class="post-update" value="Update comment"> <a href="#" class="post-cancel">Cancel</a> </div> </script> <script aria-hidden="true" type="text/template" id="thread-list-item-template"> <li data-id="<%- id %>" class="forum-nav-thread<% if (typeof(read) != "undefined" && !read) { %> is-unread<% } %>"> <a href="#" class="forum-nav-thread-link"> <div class="forum-nav-thread-wrapper-0"> <% var icon_class, sr_text; if (thread_type == "discussion") { icon_class = "fa-comments"; sr_text = "discussion"; } else if (endorsed) { icon_class = "fa-check-square-o"; sr_text = "answered question"; } else { icon_class = "fa-question"; sr_text = "unanswered question"; } %> <span class="sr"><%= sr_text %></span> <i class="icon fa <%= icon_class %>"></i> </div><div class="forum-nav-thread-wrapper-1"> <span class="forum-nav-thread-title"><%- title %></span> <% var labels = ""; if (pinned) { labels += '<li class="post-label-pinned"><i class="icon fa fa-thumb-tack"></i>Pinned</li> '; } if (typeof(subscribed) != "undefined" && subscribed) { labels += '<li class="post-label-following"><i class="icon fa fa-star"></i>Following</li> '; } if (staff_authored) { labels += '<li class="post-label-by-staff"><i class="icon fa fa-user"></i>By: Staff</li> '; } if (community_ta_authored) { labels += '<li class="post-label-by-community-ta"><i class="icon fa fa-user"></i>By: Community TA</li> '; } if (labels != "") { print('<ul class="forum-nav-thread-labels">' + labels + '</ul>'); } %> </div><div class="forum-nav-thread-wrapper-2"> <span class="forum-nav-thread-votes-count">+<%= interpolate( '%(votes_up_count)s%(span_sr_open)s votes %(span_close)s', {'span_sr_open': '<span class="sr">', 'span_close': '</span>', 'votes_up_count': votes['up_count']}, true ) %></span> <span class="forum-nav-thread-comments-count <% if (unread_comments_count > 0) { %>is-unread<% } %>"> <% var fmt; // Counts in data do not include the post itself, but the UI should var data = { 'span_sr_open': '<span class="sr">', 'span_close': '</span>', 'unread_comments_count': unread_comments_count + (read ? 0 : 1), 'comments_count': comments_count + 1 }; if (unread_comments_count > 0) { fmt = '%(comments_count)s %(span_sr_open)scomments (%(unread_comments_count)s unread comments)%(span_close)s'; } else { fmt = '%(comments_count)s %(span_sr_open)scomments %(span_close)s'; } print(interpolate(fmt, data, true)); %> </span> </div> </a> </li> </script> <script aria-hidden="true" type="text/template" id="discussion-home"> <div class="discussion-article blank-slate"> <section class="home-header"> <span class="label">DISCUSSION HOME:</span> <h1 class="home-title">Paradox and Infinity</h1> </section> <span class="label label-settings"> How to use edX discussions </span> <table class="home-helpgrid"> <tr class="helpgrid-row helpgrid-row-navigation"> <td class="row-title">Find discussions</td> <td class="row-item"> <i class="icon fa fa-reorder"></i> <span class="row-description">Focus in on specific topics</span> </td> <td class="row-item"> <i class="icon fa fa-search"></i> <span class="row-description">Search for specific posts </span> </td> <td class="row-item"> <i class="icon fa fa-sort"></i> <span class="row-description">Sort by date, vote, or comments</span> </td> </tr> <tr class="helpgrid-row helpgrid-row-participation"> <td class="row-title">Engage with posts</td> <td class="row-item"> <i class="icon fa fa-plus"></i> <span class="row-description">Upvote posts and good responses</span> </td> <td class="row-item"> <i class="icon fa fa-flag"></i> <span class="row-description">Report Forum Misuse</span> </td> <td class="row-item"> <i class="icon fa fa-star"></i> <span class="row-description">Follow posts for updates</span> </td> </tr> <tr class="helpgrid-row helpgrid-row-notification"> <td class="row-title">Receive updates</td> <td class="row-item-full" colspan="3"> <label for="email-setting-checkbox"> <span class="sr">Toggle Notifications Setting</span> <span class="notification-checkbox"> <input type="checkbox" id="email-setting-checkbox" class="email-setting" name="email-notification"/> <i class="icon fa fa-envelope"></i> </span> </label> <span class="row-description">Check this box to receive an email digest once a day notifying you about new, unread activity from posts you are following.</span> </td> </tr> </table> </div> </script> <script aria-hidden="true" type="text/template" id="search-alert-template"> <div class="search-alert" id="search-alert-<%- cid %>"> <div class="search-alert-content"> <p class="message"><%= message %></p> </div> <div class="search-alert-controls"> <a href="#" class="dismiss control control-dismiss"><i class="icon fa fa-remove"></i></a> </div> </div> </script> <script aria-hidden="true" type="text/template" id="new-post-template"> <form class="forum-new-post-form"> <ul class="post-errors" style="display: none"></ul> <div class="forum-new-post-form-wrapper"></div> <% if (cohort_options) { %> <div class="post-field group-selector-wrapper<% if (!is_commentable_cohorted) { %> disabled<% } %>" > <label class="field-label"> <span class="field-label-text"> Visible To: </span><select aria-describedby="field_help_visible_to" class="field-input js-group-select" name="group_id" <% if (!is_commentable_cohorted) { %>disabled<% } %>> <option value="">All Groups</option> <% _.each(cohort_options, function(opt) { %> <option value="<%= opt.value %>" <% if (opt.selected) { %>selected<% } %>><%- opt.text %></option> <% }); %> </select> </label><div class="field-help" id="field_help_visible_to"> Discussion admins, moderators, and TAs can make their posts visible to all students or specify a single cohort. </div> </div> <% } %> <div class="post-field"> <label class="field-label"> <span class="sr">Title:</span> <input aria-describedby="field_help_title" type="text" class="field-input js-post-title" name="title" placeholder="Title"> </label><span class="field-help" id="field_help_title"> Add a clear and descriptive title to encourage participation. </span> </div> <div class="post-field js-post-body editor" name="body" data-placeholder="Enter your question or comment"></div> <div class="post-options"> <label class="post-option is-enabled"> <input type="checkbox" name="follow" class="post-option-input js-follow" checked> <i class="icon fa fa-star"></i>follow this post </label> <% if (allow_anonymous) { %> <label class="post-option"> <input type="checkbox" name="anonymous" class="post-option-input js-anon"> post anonymously </label> <% } %> <% if (allow_anonymous_to_peers) { %> <label class="post-option"> <input type="checkbox" name="anonymous_to_peers" class="post-option-input js-anon-peers"> post anonymously to classmates </label> <% } %> </div> <div> <input type="submit" class="submit" value="Add Post"> <a href="#" class="cancel">Cancel</a> </div> </form> </script> <script aria-hidden="true" type="text/template" id="thread-type-template"> <div class="post-field"> <div class="field-label"> <span class="field-label-text"> Post type: </span><fieldset class="field-input"><legend class="sr">Post type:</legend> <input aria-describedby="field_help_post_type" type="radio" name="<%= form_id %>-post-type" class="post-type-input" id="<%= form_id %>-post-type-question" value="question"> <label for="<%= form_id %>-post-type-question" class="post-type-label"> <i class="icon fa fa-question"></i> Question </label> <input aria-describedby="field_help_post_type" type="radio" name="<%= form_id %>-post-type" class="post-type-input" id="<%= form_id %>-post-type-discussion" value="discussion" checked> <label for="<%= form_id %>-post-type-discussion" class="post-type-label"> <i class="icon fa fa-comments"></i> Discussion </label> </fieldset> </div><span class="field-help" id="field_help_post_type"> Questions raise issues that need answers. Discussions share ideas and start conversations. </span> </div> </script> <script aria-hidden="true" type="text/template" id="new-post-menu-entry-template"> <li role="menuitem" class="topic-menu-item"> <a href="#" class="topic-title" data-discussion-id="<%- id %>" data-cohorted="<%- is_cohorted %>"><%- text %></a> </li> </script> <script aria-hidden="true" type="text/template" id="new-post-menu-category-template"> <li role="menuitem" class="topic-menu-item"> <span class="topic-title"><%- text %></span> <ul role="menu" class="topic-submenu"><%= entries %></ul> </li> </script> <script aria-hidden="true" type="text/template" id="topic-template"> <div class="field-label"> <span class="field-label-text">Topic Area:</span><div class="field-input post-topic"> <a href="#" class="post-topic-button"> <span class="sr">Discussion topics; current selection is: </span> <span class="js-selected-topic"></span> <span class="drop-arrow" aria-hidden="true">▾</span> </a> <div class="topic-menu-wrapper"> <label class="topic-filter-label"> <span class="sr">Filter topics</span> <input aria-describedby="field_help_topic_area" type="text" class="topic-filter-input" placeholder="Filter topics"> </label> <ul class="topic-menu" role="menu"><%= topics_html %></ul> </div> </div> </div><span class="field-help" id="field_help_topic_area"> Add your post to a relevant topic to help others find it. </span> </script> <script type="text/template" id="forum-action-endorse"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-endorse" role="checkbox" aria-checked="false"> <span class="sr">Endorse</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Endorse</span> <span class="label-checked">Unendorse</span> </span> <span class="action-icon"><i class="icon fa fa-check"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-answer"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-answer" role="checkbox" aria-checked="false"> <span class="sr">Mark as Answer</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Mark as Answer</span> <span class="label-checked">Unmark as Answer</span> </span> <span class="action-icon"><i class="icon fa fa-check"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-follow"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-follow" role="checkbox" aria-checked="false"> <span class="sr">Follow</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Follow</span> <span class="label-checked">Unfollow</span> </span> <span class="action-icon"><i class="icon fa fa-star"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-vote"> <li class="actions-item"> <span aria-hidden="true" class="display-vote" > <span class="vote-count"></span> </span> <a href="#" class="action-button action-vote" role="checkbox" aria-checked="false"> <span class="sr">Vote for this post,&nbsp;</span> <span class="sr js-sr-vote-count"></span> <span class="action-label" aria-hidden="true"> <span class="vote-count"></span> </span> <span class="action-icon" aria-hidden="true"> <i class="icon fa fa-plus"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-report"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-report" role="checkbox" aria-checked="false"> <span class="sr">Report abuse</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Report</span> <span class="label-checked">Unreport</span> </span> <span class="action-icon"> <i class="icon fa fa-flag"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-pin"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-pin" role="checkbox" aria-checked="false"> <span class="sr">Pin</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Pin</span> <span class="label-checked">Unpin</span> </span> <span class="action-icon"> <i class="icon fa fa-thumb-tack"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-close"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-close" role="checkbox" aria-checked="false"> <span class="sr">Close</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Close</span> <span class="label-checked">Open</span> </span> <span class="action-icon"> <i class="icon fa fa-lock"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-edit"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-edit" role="button"> <span class="action-label">Edit</span> <span class="action-icon"><i class="icon fa fa-pencil"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-delete"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-delete" role="button"> <span class="action-label">Delete</span> <span class="action-icon"><i class="icon fa fa-remove"></i></span> </a> </li> </script> <script type="text/template" id="forum-actions"> <ul class="<%= contentType %>-actions-list"> <% _.each(primaryActions, function(action) { print(_.template($('#forum-action-' + action).html(), {})) }) %> <li class="actions-item is-visible"> <div class="more-wrapper"> <a href="javascript:void(0)" class="action-button action-more" role="button" aria-haspopup="true" aria-controls="action-menu-<%= contentId %>"> <span class="action-label">More</span> <span class="action-icon"><i class="icon fa fa-ellipsis-h"></i></span> </a> <div class="actions-dropdown" id="action-menu-<%= contentType %>" aria-expanded="false"> <ul class="actions-dropdown-list"> <% _.each(secondaryActions, function(action) { print(_.template($('#forum-action-' + action).html(), {})) }) %> </ul> </div> </div> </li> </ul> </script> <script aria-hidden="true" type="text/template" id="post-user-display-template"> <% if (username) { %> <a href="<%- user_url %>" class="username"><%- username %></a> <% if (is_community_ta) { %> <span class="user-label-community-ta">Community TA</span> <% } else if (is_staff) { %> <span class="user-label-staff">Staff</span> <% } %> <% } else { %> anonymous <% } %> </script> <div class="discussion-module" data-discussion-id="e3994bf57a903fab2ac912eda29db5730a36551a"> <a class="discussion-show control-button" href="javascript:void(0)" data-discussion-id="e3994bf57a903fab2ac912eda29db5730a36551a" role="button"><span class="show-hide-discussion-icon"></span><span class="button-text">Show Discussion</span></a> <a href="#" class="new-post-btn" role="button"><span class="icon fa fa-edit new-post-icon"></span>New Post</a> </div> </div> </div> </div> </div>
<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-usage-id="block-v1:MITx+24.118x+2T2015+type@vertical+block@40d459f145054e81be1bb94bc449fae3" data-block-type="vertical" data-course-id="course-v1:MITx+24.118x+2T2015"> <div class="vert-mod"> <div class="vert vert-0" data-id="block-v1:MITx+24.118x+2T2015+type@html+block@83e2fad7b19440b8aa5f75fb5995cfa9"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@html+block@83e2fad7b19440b8aa5f75fb5995cfa9" data-type="HTMLModule" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h3>The Grandfather Paradox</h3> <p></p> <p><span style="font-family: 'book antiqua', palatino;">Consider Bruno. Bruno hates his grandfather, and not without reason. Grandfather was a terrible man: he was a gambler and a drunk. Not just that. Grandfather orchestrated a large-scale fraud, which left hundreds of people in poverty. Nothing would please Bruno more than killing Grandfather. But there is a problem: Grandfather died many years ago, long before Bruno was born. Undeterred, Bruno builds a time machine and travels to September 13, 1937, a time before Grandfather had children, and before he orchestrated the fraud. Nothing will stop him from killing Grandfather now!</span></p> <p><span style="font-family: 'book antiqua', palatino;">After weeks of careful planning, the moment of truth has arrived. Bruno has climbed up a church steeple, and positioned himself at the belfry with a sniper&rsquo;s rifle. Grandfather is on his morning walk. Bruno spots him, and aims his rifle with the precision of an expert gunman. Grandfather stops to tie his shoelaces. The church bells start ringing. Noon has arrived. Bruno caresses the trigger. Grandfather stands still for a moment, as a breeze ruffles the trees nearby. Bruno prepares to shoot&hellip;What happens next?</span></p> <p><span face="book antiqua, palatino" style="font-family: 'book antiqua', palatino;">Suppose Bruno kills Grandfather. Then Grandfather will never have children. So Bruno's mother will never be born. So she will never have Bruno. So Bruno won&rsquo;t go back in time. So he won&rsquo;t kill Granfather. So if he kills Grandfather, he won't kill Grandfather. Contradiction! Paradox!</span></p> <p><span face="book antiqua, palatino" style="font-family: 'book antiqua', palatino;">So it can&rsquo;t be that Bruno kills Granfather. But what&rsquo;s to stop him?</span></p> <p><span face="book antiqua, palatino" style="font-family: 'book antiqua', palatino;">Here is a tempting thought: it must be that Bruno could never have been in a position to kill Grandfather. He must not have been able to go back in time, contrary to our initial assumption. According to this thought, our story is a&nbsp;<em>reductio</em> of the idea of time-travel &mdash; that is, it shows that the assumption that time-travel is possible leads to contradiction, and thus shows that time-travel is an inherently contradictory idea, like a square circle.<em>&nbsp;</em></span></p> <p><span style="font-family: 'book antiqua', palatino;">I don&rsquo;t think that's the right way of thinking about the situation. This is what I think we should say instead. When we hear the story, we know that somehow Grandfather will survive. We know this because it follows from the earlier part of my narrative that Grandfather will live long enough to have children, and the only way for this to happen is for Bruno&rsquo;s 1937 assassination attempt to fail. But why will Bruno fail? It will probably be for&nbsp;some&nbsp;perfectly mundane reason.&nbsp;Perhaps he will lose his nerve at the last minute; perhaps he will get distracted by the barking of a nearby dog; perhaps he will slip on a banana peel; perhaps his trigger will get stuck. </span></p> <p><span style="font-family: 'book antiqua', palatino;">Of course, the issue is not settled by the story so far. Our story offers us no particular clue as to what stops Bruno; in fact, the way the story is told makes any particular reason seem very arbitrary. But arbitrary is not the same as inconsistent. What we know is that, as long as the story is consistent, the assassination attempt will somehow fail. It will fail, because it already has failed.</span></p> <p></p> </div> </div> <div class="vert vert-1" data-id="block-v1:MITx+24.118x+2T2015+type@video+block@3be4207325434121bae9e12ed47b5ca2"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@video+block@3be4207325434121bae9e12ed47b5ca2" data-type="Video" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>Video Review: The Grandfather Paradox</h2> <div id="video_3be4207325434121bae9e12ed47b5ca2" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "MIT24118T314-V000600_DTH", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@3be4207325434121bae9e12ed47b5ca2/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": ["https://d2f1egay8yehza.cloudfront.net/mit-24118/MIT24118T314-V000600_DTH.mp4"], "autohideHtml5": false, "streams": "1.00:-LVhT2vofPo", "saveStateUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@3be4207325434121bae9e12ed47b5ca2/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@3be4207325434121bae9e12ed47b5ca2/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_3be4207325434121bae9e12ed47b5ca2" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="3be4207325434121bae9e12ed47b5ca2"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_3be4207325434121bae9e12ed47b5ca2" href="#after-transcript_3be4207325434121bae9e12ed47b5ca2">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_3be4207325434121bae9e12ed47b5ca2" href="#before-transcript_3be4207325434121bae9e12ed47b5ca2">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/mit-24118/MIT24118T314-V000600_DTH.mp4">Download video</a> </li> </ul> </div> </div> </div> <div class="vert vert-2" data-id="block-v1:MITx+24.118x+2T2015+type@html+block@53f29994aa194025a3f44259b9efa095"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@html+block@53f29994aa194025a3f44259b9efa095" data-type="HTMLModule" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h3>Could an all-powerful God make Bruno kill Granfather?</h3> <p></p> <p><span style="font-family: book antiqua,palatino;">Not even an all-powerful God could make a world in which Bruno kills his grandfather before his grandfather has children.<br /></span></p> <p><span style="font-family: book antiqua,palatino;">How do we know this? Because </span><span style="font-family: book antiqua,palatino;"><span style="font-family: book antiqua,palatino;">not even an all-powerful God could bring about an <em>inconsistent</em> state of affairs, and </span>a world in which a grandfather gets killed before having children would be inconsistent. <br /></span></p> <p><span style="font-family: book antiqua,palatino;">Here is a picture that I sometimes find helpful. Imagine that the way God makes the world is by starting with a grid of space-time points, and then deciding what physical properites to fill each space-time point with (in some God places positive charge; in some She places mass). Since we are assuming that our God is all-powerful, She can fill each space-time point however She likes (or leave it blank). On some ways of filling out space-time points, the world will be such that someone kills his grandfather. On other ways of filling out space-time points, the world will be such that someone travels back in time and kills someone before that person has children. But there is no way of filling out space-time points whereby the world is <em>both</em> such that someone kills his grandfather <em>and</em> such that he does so by travelling back in time to kill him before his grandfather has children.</span></p> <p><span style="font-family: book antiqua,palatino;">(<em>A comparison:</em> Suppose you are allowed to paint each of the points on a sheet of paper any color you like. Could you draw a figure that is both a circle and a sqaure? You cannot: there is no way of filling out points on a page that would yield such a figure.)</span></p> <p></p> </div> </div> <div class="vert vert-3" data-id="block-v1:MITx+24.118x+2T2015+type@html+block@9766fb9c7ff94e26ac764c7ee42bae36"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@html+block@9766fb9c7ff94e26ac764c7ee42bae36" data-type="HTMLModule" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h3>What about Contemporary Physics?</h3> <p></p> <p><span style="font-family: book antiqua,palatino;">I hope to have convinced you that a world in which Bruno kills his grandfather before his grandfather has children would be inconsistent.</span><span style="font-family: book antiqua,palatino;"></span></p> <p><span style="font-family: book antiqua,palatino;">Since the laws of physics are consistent, this means that any scenario consistent with the laws of physics is a scenario in which it is not the case that Bruno kills his grandfather before his grandfather has children. But how does this work? How, exactly, does it come about that paradoxical scenarios get ruled out by the laws of physics? (Why is any scenario in which Bruno travels back in time to kill Grandfather also a scenario in which he either looses his nerve, or slips on a bannana peel, or <em>something</em>?)<br /></span></p> <p><span style="font-family: book antiqua,palatino;">The first thing to note is that the particular way in which a system of physical laws rules out paradoxical scenarios need not be especially interesting. (To see this, consider the question of how the laws of physics rule out a scenario in which I draw a figure that is both a circle and a square.) </span></p> <p><span style="font-family: book antiqua,palatino;">But is there anything more substantial to be said? </span></p> <p><span style="font-family: book antiqua,palatino;">The simplest interesting way for a system of physical laws to rule out a scenario in which someone kills his own grandfather before his grandfather has children is for the laws to exclude time-travel altogether. As it turns out, however, it is not clear that this is true of the actual laws of physics, since there are solutions to Einstein&rsquo;s equations which allow for time-travel. (See&nbsp;<a href="http://plato.stanford.edu/entries/time-travel-phys/" target="[object Object]">here</a> for more information.)</span></p> <p><span style="font-family: book antiqua,palatino;">Some systems of laws that allow for time travel turn out to exclude paradoxical scenarios in interesting ways. If you&rsquo;d like to know more, have a look at&nbsp;<a href="http://plato.stanford.edu/entries/time-travel-phys/#5" target="[object Object]">these</a> toy examples. Even better: have a look at the&nbsp;<a href="/courses/course-v1:MITx+24.118x+2T2015/jump_to_id/533e67901b4f451cbb28589bd02f9ce1" target="[object Object]">Bonus Section</a> below, in which MIT physicist Alan Guth tackles the question of whether it is physically possible to build a time machine.<br /></span></p> <p></p> </div> </div> <div class="vert vert-4" data-id="block-v1:MITx+24.118x+2T2015+type@discussion+block@7b43f4e018f1495d940d025a6cabdf4d"> <div class="xblock xblock-student_view xblock-student_view-discussion xmodule_display xmodule_DiscussionModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="discussion" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@discussion+block@7b43f4e018f1495d940d025a6cabdf4d" data-type="InlineDiscussion" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "InlineDiscussion"} </script> <script aria-hidden="true" type="text/template" id="thread-template"> <article class="discussion-article" data-id="<%- id %>"> <div class="thread-wrapper" tabindex="-1"> <div class="forum-thread-main-wrapper"> <div class="thread-content-wrapper"></div> <div class="post-extended-content"> <ol class="responses js-marked-answer-list"></ol> </div> </div> <div class="post-extended-content"> <div class="response-count"/> <div class="add-response"> <button class="button add-response-btn"> <i class="icon fa fa-reply"></i> <span class="add-response-btn-text">Add A Response</span> </button> </div> <ol class="responses js-response-list"/> <div class="response-pagination"/> <div class="post-status-closed bottom-post-status" style="display: none"> This thread is closed. </div> <form class="discussion-reply-new" data-id="<%- id %>"> <h4>Post a response:</h4> <ul class="discussion-errors"></ul> <div class="reply-body" data-id="<%- id %>"></div> <div class="reply-post-control"> <a class="discussion-submit-post control-button" href="#">Submit</a> </div> </form> </div> </div> <div class="post-tools"> <a href="javascript:void(0)" class="forum-thread-expand"><span class="icon fa fa-plus"/> Expand discussion</a> <a href="javascript:void(0)" class="forum-thread-collapse"><span class="icon fa fa-minus"/> Collapse discussion</a> </div> </article> </script> <script aria-hidden="true" type="text/template" id="thread-show-template"> <div class="discussion-post"> <header> <div class="group-visibility-label"> <% if (obj.group_name) { %> <%- interpolate( gettext('This post is visible only to %(group_name)s.'), {group_name: obj.group_name}, true ) %> <% } else { %> <%- gettext('This post is visible to everyone.') %> <% } %> </div> <div class="post-header-content"> <h1><%- title %></h1> <p class="posted-details"> <% var timeAgoHtml = interpolate( '<span class="timeago" title="%(created_at)s">%(created_at)s</span>', {created_at: created_at}, true ); %> <%= interpolate( // Translators: post_type describes the kind of post this is (e.g. "question" or "discussion"); // time_ago is how much time has passed since the post was created (e.g. "4 hours ago") _.escape(gettext('%(post_type)s posted %(time_ago)s by %(author)s')), {post_type: thread_type, time_ago: timeAgoHtml, author: author_display}, true ) %> </p> <div class="post-labels"> <span class="post-label-pinned"><i class="icon fa fa-thumb-tack"></i><%- gettext("Pinned") %></span> <span class="post-label-reported"><i class="icon fa fa-flag"></i><%- gettext("Reported") %></span> <span class="post-label-closed"><i class="icon fa fa-lock"></i><%- gettext("Closed") %></span> </div> </div> <div class="post-header-actions post-extended-content"> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'post', primaryActions: ['vote', 'follow'], secondaryActions: ['pin', 'edit', 'delete', 'report', 'close'] } ) %> </div> </header> <div class="post-body"><%- body %></div> <% if (mode == "tab" && obj.courseware_url) { %> <% var courseware_title_linked = interpolate( '<a href="%(courseware_url)s">%(courseware_title)s</a>', {courseware_url: courseware_url, courseware_title: _.escape(courseware_title)}, true ); %> <div class="post-context"> <%= interpolate( _.escape(gettext('Related to: %(courseware_title_linked)s')), {courseware_title_linked: courseware_title_linked}, true ) %> </div> <% } %> </div> </script> <script aria-hidden="true" type="text/template" id="thread-edit-template"> <h1>Editing post</h1> <ul class="post-errors"></ul> <div class="forum-edit-post-form-wrapper"></div> <div class="form-row"> <label class="sr" for="edit-post-title">Edit post title</label> <input type="text" id="edit-post-title" class="edit-post-title" name="title" value="<%-title %>" placeholder="Title"> </div> <div class="form-row"> <div class="edit-post-body" name="body"><%- body %></div> </div> <input type="submit" id="edit-post-submit" class="post-update" value="Update post"> <a href="#" class="post-cancel">Cancel</a> </script> <script aria-hidden="true" type="text/template" id="thread-response-template"> <div class="discussion-response"></div> <a href="#" class="action-show-comments"> <%- interpolate('Show Comments (%(num_comments)s)', {num_comments: comments.length}, true) %> <i class="icon fa fa-caret-down"></i> </a> <ol class="comments"> <li class="new-comment"> <form class="comment-form" data-id="<%- wmdId %>"> <ul class="discussion-errors"></ul> <label class="sr" for="add-new-comment">Add a comment</label> <div class="comment-body" id="add-new-comment" data-id="<%- wmdId %>" data-placeholder="Add a comment"></div> <div class="comment-post-control"> <a class="discussion-submit-comment control-button" href="#">Submit</a> </div> </form> </li> </ol> </script> <script aria-hidden="true" type="text/template" id="thread-response-show-template"> <header> <div class="response-header-content"> <%= author_display %> <p class="posted-details"> <span class="timeago" title="<%= created_at %>"><%= created_at %></span> <% if (obj.endorsement) { %> - <%= interpolate( thread.get("thread_type") == "question" ? (endorsement.username ? "marked as answer %(time_ago)s by %(user)s" : "marked as answer %(time_ago)s") : (endorsement.username ? "endorsed %(time_ago)s by %(user)s" : "endorsed %(time_ago)s"), { 'time_ago': '<span class="timeago" title="' + endorsement.time + '">' + endorsement.time + '</span>', 'user': endorser_display }, true )%><% } %> </p> <div class="post-labels"> <span class="post-label-reported"><i class="icon fa fa-flag"></i>Reported</span> </div> </div> <div class="response-header-actions"> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'response', primaryActions: ['vote', thread.get('thread_type') == 'question' ? 'answer' : 'endorse'], secondaryActions: ['edit', 'delete', 'report'] } ) %> </div> </header> <div class="response-body"><%- body %></div> </script> <script aria-hidden="true" type="text/template" id="thread-response-edit-template"> <div class="edit-post-form"> <h1>Editing response</h1> <ul class="edit-post-form-errors"></ul> <div class="form-row"> <div class="edit-post-body" name="body" data-id="<%- id %>"><%- body %></div> </div> <input type="submit" id="edit-response-submit"class="post-update" value="Update response"> <a href="#" class="post-cancel">Cancel</a> </div> </script> <script aria-hidden="true" type="text/template" id="response-comment-show-template"> <div id="comment_<%- id %>"> <div class="response-body"><%- body %></div> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'comment', primaryActions: [], secondaryActions: ['edit', 'delete', 'report'] } ) %> <p class="posted-details"> <%= interpolate( 'posted %(time_ago)s by %(author)s', {'time_ago': '<span class="timeago" title="' + created_at + '">' + created_at + '</span>', 'author': author_display}, true )%> </p> <div class="post-labels"> <span class="post-label-reported"><i class="icon fa fa-flag"></i>Reported</span> </div> </div> </script> <script aria-hidden="true" type="text/template" id="response-comment-edit-template"> <div class="edit-post-form" id="comment_<%- id %>"> <h1>Editing comment</h1> <ul class="edit-comment-form-errors"></ul> <div class="form-row"> <div class="edit-comment-body" name="body" data-id="<%- id %>"><%- body %></div> </div> <input type="submit" id="edit-comment-submit" class="post-update" value="Update comment"> <a href="#" class="post-cancel">Cancel</a> </div> </script> <script aria-hidden="true" type="text/template" id="thread-list-item-template"> <li data-id="<%- id %>" class="forum-nav-thread<% if (typeof(read) != "undefined" && !read) { %> is-unread<% } %>"> <a href="#" class="forum-nav-thread-link"> <div class="forum-nav-thread-wrapper-0"> <% var icon_class, sr_text; if (thread_type == "discussion") { icon_class = "fa-comments"; sr_text = "discussion"; } else if (endorsed) { icon_class = "fa-check-square-o"; sr_text = "answered question"; } else { icon_class = "fa-question"; sr_text = "unanswered question"; } %> <span class="sr"><%= sr_text %></span> <i class="icon fa <%= icon_class %>"></i> </div><div class="forum-nav-thread-wrapper-1"> <span class="forum-nav-thread-title"><%- title %></span> <% var labels = ""; if (pinned) { labels += '<li class="post-label-pinned"><i class="icon fa fa-thumb-tack"></i>Pinned</li> '; } if (typeof(subscribed) != "undefined" && subscribed) { labels += '<li class="post-label-following"><i class="icon fa fa-star"></i>Following</li> '; } if (staff_authored) { labels += '<li class="post-label-by-staff"><i class="icon fa fa-user"></i>By: Staff</li> '; } if (community_ta_authored) { labels += '<li class="post-label-by-community-ta"><i class="icon fa fa-user"></i>By: Community TA</li> '; } if (labels != "") { print('<ul class="forum-nav-thread-labels">' + labels + '</ul>'); } %> </div><div class="forum-nav-thread-wrapper-2"> <span class="forum-nav-thread-votes-count">+<%= interpolate( '%(votes_up_count)s%(span_sr_open)s votes %(span_close)s', {'span_sr_open': '<span class="sr">', 'span_close': '</span>', 'votes_up_count': votes['up_count']}, true ) %></span> <span class="forum-nav-thread-comments-count <% if (unread_comments_count > 0) { %>is-unread<% } %>"> <% var fmt; // Counts in data do not include the post itself, but the UI should var data = { 'span_sr_open': '<span class="sr">', 'span_close': '</span>', 'unread_comments_count': unread_comments_count + (read ? 0 : 1), 'comments_count': comments_count + 1 }; if (unread_comments_count > 0) { fmt = '%(comments_count)s %(span_sr_open)scomments (%(unread_comments_count)s unread comments)%(span_close)s'; } else { fmt = '%(comments_count)s %(span_sr_open)scomments %(span_close)s'; } print(interpolate(fmt, data, true)); %> </span> </div> </a> </li> </script> <script aria-hidden="true" type="text/template" id="discussion-home"> <div class="discussion-article blank-slate"> <section class="home-header"> <span class="label">DISCUSSION HOME:</span> <h1 class="home-title">Paradox and Infinity</h1> </section> <span class="label label-settings"> How to use edX discussions </span> <table class="home-helpgrid"> <tr class="helpgrid-row helpgrid-row-navigation"> <td class="row-title">Find discussions</td> <td class="row-item"> <i class="icon fa fa-reorder"></i> <span class="row-description">Focus in on specific topics</span> </td> <td class="row-item"> <i class="icon fa fa-search"></i> <span class="row-description">Search for specific posts </span> </td> <td class="row-item"> <i class="icon fa fa-sort"></i> <span class="row-description">Sort by date, vote, or comments</span> </td> </tr> <tr class="helpgrid-row helpgrid-row-participation"> <td class="row-title">Engage with posts</td> <td class="row-item"> <i class="icon fa fa-plus"></i> <span class="row-description">Upvote posts and good responses</span> </td> <td class="row-item"> <i class="icon fa fa-flag"></i> <span class="row-description">Report Forum Misuse</span> </td> <td class="row-item"> <i class="icon fa fa-star"></i> <span class="row-description">Follow posts for updates</span> </td> </tr> <tr class="helpgrid-row helpgrid-row-notification"> <td class="row-title">Receive updates</td> <td class="row-item-full" colspan="3"> <label for="email-setting-checkbox"> <span class="sr">Toggle Notifications Setting</span> <span class="notification-checkbox"> <input type="checkbox" id="email-setting-checkbox" class="email-setting" name="email-notification"/> <i class="icon fa fa-envelope"></i> </span> </label> <span class="row-description">Check this box to receive an email digest once a day notifying you about new, unread activity from posts you are following.</span> </td> </tr> </table> </div> </script> <script aria-hidden="true" type="text/template" id="search-alert-template"> <div class="search-alert" id="search-alert-<%- cid %>"> <div class="search-alert-content"> <p class="message"><%= message %></p> </div> <div class="search-alert-controls"> <a href="#" class="dismiss control control-dismiss"><i class="icon fa fa-remove"></i></a> </div> </div> </script> <script aria-hidden="true" type="text/template" id="new-post-template"> <form class="forum-new-post-form"> <ul class="post-errors" style="display: none"></ul> <div class="forum-new-post-form-wrapper"></div> <% if (cohort_options) { %> <div class="post-field group-selector-wrapper<% if (!is_commentable_cohorted) { %> disabled<% } %>" > <label class="field-label"> <span class="field-label-text"> Visible To: </span><select aria-describedby="field_help_visible_to" class="field-input js-group-select" name="group_id" <% if (!is_commentable_cohorted) { %>disabled<% } %>> <option value="">All Groups</option> <% _.each(cohort_options, function(opt) { %> <option value="<%= opt.value %>" <% if (opt.selected) { %>selected<% } %>><%- opt.text %></option> <% }); %> </select> </label><div class="field-help" id="field_help_visible_to"> Discussion admins, moderators, and TAs can make their posts visible to all students or specify a single cohort. </div> </div> <% } %> <div class="post-field"> <label class="field-label"> <span class="sr">Title:</span> <input aria-describedby="field_help_title" type="text" class="field-input js-post-title" name="title" placeholder="Title"> </label><span class="field-help" id="field_help_title"> Add a clear and descriptive title to encourage participation. </span> </div> <div class="post-field js-post-body editor" name="body" data-placeholder="Enter your question or comment"></div> <div class="post-options"> <label class="post-option is-enabled"> <input type="checkbox" name="follow" class="post-option-input js-follow" checked> <i class="icon fa fa-star"></i>follow this post </label> <% if (allow_anonymous) { %> <label class="post-option"> <input type="checkbox" name="anonymous" class="post-option-input js-anon"> post anonymously </label> <% } %> <% if (allow_anonymous_to_peers) { %> <label class="post-option"> <input type="checkbox" name="anonymous_to_peers" class="post-option-input js-anon-peers"> post anonymously to classmates </label> <% } %> </div> <div> <input type="submit" class="submit" value="Add Post"> <a href="#" class="cancel">Cancel</a> </div> </form> </script> <script aria-hidden="true" type="text/template" id="thread-type-template"> <div class="post-field"> <div class="field-label"> <span class="field-label-text"> Post type: </span><fieldset class="field-input"><legend class="sr">Post type:</legend> <input aria-describedby="field_help_post_type" type="radio" name="<%= form_id %>-post-type" class="post-type-input" id="<%= form_id %>-post-type-question" value="question"> <label for="<%= form_id %>-post-type-question" class="post-type-label"> <i class="icon fa fa-question"></i> Question </label> <input aria-describedby="field_help_post_type" type="radio" name="<%= form_id %>-post-type" class="post-type-input" id="<%= form_id %>-post-type-discussion" value="discussion" checked> <label for="<%= form_id %>-post-type-discussion" class="post-type-label"> <i class="icon fa fa-comments"></i> Discussion </label> </fieldset> </div><span class="field-help" id="field_help_post_type"> Questions raise issues that need answers. Discussions share ideas and start conversations. </span> </div> </script> <script aria-hidden="true" type="text/template" id="new-post-menu-entry-template"> <li role="menuitem" class="topic-menu-item"> <a href="#" class="topic-title" data-discussion-id="<%- id %>" data-cohorted="<%- is_cohorted %>"><%- text %></a> </li> </script> <script aria-hidden="true" type="text/template" id="new-post-menu-category-template"> <li role="menuitem" class="topic-menu-item"> <span class="topic-title"><%- text %></span> <ul role="menu" class="topic-submenu"><%= entries %></ul> </li> </script> <script aria-hidden="true" type="text/template" id="topic-template"> <div class="field-label"> <span class="field-label-text">Topic Area:</span><div class="field-input post-topic"> <a href="#" class="post-topic-button"> <span class="sr">Discussion topics; current selection is: </span> <span class="js-selected-topic"></span> <span class="drop-arrow" aria-hidden="true">▾</span> </a> <div class="topic-menu-wrapper"> <label class="topic-filter-label"> <span class="sr">Filter topics</span> <input aria-describedby="field_help_topic_area" type="text" class="topic-filter-input" placeholder="Filter topics"> </label> <ul class="topic-menu" role="menu"><%= topics_html %></ul> </div> </div> </div><span class="field-help" id="field_help_topic_area"> Add your post to a relevant topic to help others find it. </span> </script> <script type="text/template" id="forum-action-endorse"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-endorse" role="checkbox" aria-checked="false"> <span class="sr">Endorse</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Endorse</span> <span class="label-checked">Unendorse</span> </span> <span class="action-icon"><i class="icon fa fa-check"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-answer"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-answer" role="checkbox" aria-checked="false"> <span class="sr">Mark as Answer</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Mark as Answer</span> <span class="label-checked">Unmark as Answer</span> </span> <span class="action-icon"><i class="icon fa fa-check"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-follow"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-follow" role="checkbox" aria-checked="false"> <span class="sr">Follow</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Follow</span> <span class="label-checked">Unfollow</span> </span> <span class="action-icon"><i class="icon fa fa-star"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-vote"> <li class="actions-item"> <span aria-hidden="true" class="display-vote" > <span class="vote-count"></span> </span> <a href="#" class="action-button action-vote" role="checkbox" aria-checked="false"> <span class="sr">Vote for this post,&nbsp;</span> <span class="sr js-sr-vote-count"></span> <span class="action-label" aria-hidden="true"> <span class="vote-count"></span> </span> <span class="action-icon" aria-hidden="true"> <i class="icon fa fa-plus"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-report"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-report" role="checkbox" aria-checked="false"> <span class="sr">Report abuse</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Report</span> <span class="label-checked">Unreport</span> </span> <span class="action-icon"> <i class="icon fa fa-flag"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-pin"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-pin" role="checkbox" aria-checked="false"> <span class="sr">Pin</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Pin</span> <span class="label-checked">Unpin</span> </span> <span class="action-icon"> <i class="icon fa fa-thumb-tack"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-close"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-close" role="checkbox" aria-checked="false"> <span class="sr">Close</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Close</span> <span class="label-checked">Open</span> </span> <span class="action-icon"> <i class="icon fa fa-lock"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-edit"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-edit" role="button"> <span class="action-label">Edit</span> <span class="action-icon"><i class="icon fa fa-pencil"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-delete"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-delete" role="button"> <span class="action-label">Delete</span> <span class="action-icon"><i class="icon fa fa-remove"></i></span> </a> </li> </script> <script type="text/template" id="forum-actions"> <ul class="<%= contentType %>-actions-list"> <% _.each(primaryActions, function(action) { print(_.template($('#forum-action-' + action).html(), {})) }) %> <li class="actions-item is-visible"> <div class="more-wrapper"> <a href="javascript:void(0)" class="action-button action-more" role="button" aria-haspopup="true" aria-controls="action-menu-<%= contentId %>"> <span class="action-label">More</span> <span class="action-icon"><i class="icon fa fa-ellipsis-h"></i></span> </a> <div class="actions-dropdown" id="action-menu-<%= contentType %>" aria-expanded="false"> <ul class="actions-dropdown-list"> <% _.each(secondaryActions, function(action) { print(_.template($('#forum-action-' + action).html(), {})) }) %> </ul> </div> </div> </li> </ul> </script> <script aria-hidden="true" type="text/template" id="post-user-display-template"> <% if (username) { %> <a href="<%- user_url %>" class="username"><%- username %></a> <% if (is_community_ta) { %> <span class="user-label-community-ta">Community TA</span> <% } else if (is_staff) { %> <span class="user-label-staff">Staff</span> <% } %> <% } else { %> anonymous <% } %> </script> <div class="discussion-module" data-discussion-id="4ea60b5f550d36231e70622615988094cd938f83"> <a class="discussion-show control-button" href="javascript:void(0)" data-discussion-id="4ea60b5f550d36231e70622615988094cd938f83" role="button"><span class="show-hide-discussion-icon"></span><span class="button-text">Show Discussion</span></a> <a href="#" class="new-post-btn" role="button"><span class="icon fa fa-edit new-post-icon"></span>New Post</a> </div> </div> </div> </div> </div>
<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-usage-id="block-v1:MITx+24.118x+2T2015+type@vertical+block@bd18929f726a45c29faca4dd067e2668" data-block-type="vertical" data-course-id="course-v1:MITx+24.118x+2T2015"> <div class="vert-mod"> <div class="vert vert-0" data-id="block-v1:MITx+24.118x+2T2015+type@html+block@7c37d3ea9a994fa382851d369071fb5b"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@html+block@7c37d3ea9a994fa382851d369071fb5b" data-type="HTMLModule" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h3>WiPhi Video Summary</h3> <p><span style="font-family: 'book antiqua', palatino;">If you&rsquo;d like to see a fun summary&nbsp;of the material so far, check out the video below. It was animated&nbsp;by Damien Rochford as part of <a href="http://wi-phi.com" target="[object Object]">Wi-Phi</a>, a project which works with the Khan Academy to make philosophy more accessible to non-philosophers.</span></p> </div> </div> <div class="vert vert-1" data-id="block-v1:MITx+24.118x+2T2015+type@video+block@eb6c9fafa54b498d87f0b951baf9637e"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@video+block@eb6c9fafa54b498d87f0b951baf9637e" data-type="Video" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>Video</h2> <div id="video_eb6c9fafa54b498d87f0b951baf9637e" class="video closed" data-metadata='{"ytApiUrl": "www.youtube.com/iframe_api", "transcriptLanguage": "en", "end": 0.0, "sub": "", "showCaptions": "true", "start": 0.0, "transcriptAvailableTranslationsUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@eb6c9fafa54b498d87f0b951baf9637e/handler/transcript/available_translations", "savedVideoPosition": 0.0, "ytTestUrl": "gdata.youtube.com/feeds/api/videos/", "ytTestTimeout": 1500, "generalSpeed": 1.5, "transcriptLanguages": {"en": "English"}, "sources": [], "autohideHtml5": false, "streams": "1.00:M8oITAoaCr4", "saveStateUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@eb6c9fafa54b498d87f0b951baf9637e/handler/xmodule_handler/save_user_state", "transcriptTranslationUrl": "/courses/course-v1:MITx+24.118x+2T2015/xblock/block-v1:MITx+24.118x+2T2015+type@video+block@eb6c9fafa54b498d87f0b951baf9637e/handler/transcript/translation/__lang__", "speed": null, "captionDataDir": null, "autoplay": false}' data-bumper-metadata='null' data-poster='null' tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_eb6c9fafa54b498d87f0b951baf9637e" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="eb6c9fafa54b498d87f0b951baf9637e"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div> <div class="vcr"><div class="vidtime">0:00 / 0:00</div></div> <div class="secondary-controls"></div> </div> </section> <a class="nav-skip sr" id="before-transcript_eb6c9fafa54b498d87f0b951baf9637e" href="#after-transcript_eb6c9fafa54b498d87f0b951baf9637e">Skip to end of transcript.</a> </article> </div> <a class="nav-skip sr" id="after-transcript_eb6c9fafa54b498d87f0b951baf9637e" href="#before-transcript_eb6c9fafa54b498d87f0b951baf9637e">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> </ul> </div> </div> </div> <div class="vert vert-2" data-id="block-v1:MITx+24.118x+2T2015+type@discussion+block@e50c78bd0b824d24b94bd373bfc5ba39"> <div class="xblock xblock-student_view xblock-student_view-discussion xmodule_display xmodule_DiscussionModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="discussion" data-request-token="9b5f11e211c311e5b8fa0a8d6245fa4f" data-runtime-version="1" data-usage-id="block-v1:MITx+24.118x+2T2015+type@discussion+block@e50c78bd0b824d24b94bd373bfc5ba39" data-type="InlineDiscussion" data-course-id="course-v1:MITx+24.118x+2T2015"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "InlineDiscussion"} </script> <script aria-hidden="true" type="text/template" id="thread-template"> <article class="discussion-article" data-id="<%- id %>"> <div class="thread-wrapper" tabindex="-1"> <div class="forum-thread-main-wrapper"> <div class="thread-content-wrapper"></div> <div class="post-extended-content"> <ol class="responses js-marked-answer-list"></ol> </div> </div> <div class="post-extended-content"> <div class="response-count"/> <div class="add-response"> <button class="button add-response-btn"> <i class="icon fa fa-reply"></i> <span class="add-response-btn-text">Add A Response</span> </button> </div> <ol class="responses js-response-list"/> <div class="response-pagination"/> <div class="post-status-closed bottom-post-status" style="display: none"> This thread is closed. </div> <form class="discussion-reply-new" data-id="<%- id %>"> <h4>Post a response:</h4> <ul class="discussion-errors"></ul> <div class="reply-body" data-id="<%- id %>"></div> <div class="reply-post-control"> <a class="discussion-submit-post control-button" href="#">Submit</a> </div> </form> </div> </div> <div class="post-tools"> <a href="javascript:void(0)" class="forum-thread-expand"><span class="icon fa fa-plus"/> Expand discussion</a> <a href="javascript:void(0)" class="forum-thread-collapse"><span class="icon fa fa-minus"/> Collapse discussion</a> </div> </article> </script> <script aria-hidden="true" type="text/template" id="thread-show-template"> <div class="discussion-post"> <header> <div class="group-visibility-label"> <% if (obj.group_name) { %> <%- interpolate( gettext('This post is visible only to %(group_name)s.'), {group_name: obj.group_name}, true ) %> <% } else { %> <%- gettext('This post is visible to everyone.') %> <% } %> </div> <div class="post-header-content"> <h1><%- title %></h1> <p class="posted-details"> <% var timeAgoHtml = interpolate( '<span class="timeago" title="%(created_at)s">%(created_at)s</span>', {created_at: created_at}, true ); %> <%= interpolate( // Translators: post_type describes the kind of post this is (e.g. "question" or "discussion"); // time_ago is how much time has passed since the post was created (e.g. "4 hours ago") _.escape(gettext('%(post_type)s posted %(time_ago)s by %(author)s')), {post_type: thread_type, time_ago: timeAgoHtml, author: author_display}, true ) %> </p> <div class="post-labels"> <span class="post-label-pinned"><i class="icon fa fa-thumb-tack"></i><%- gettext("Pinned") %></span> <span class="post-label-reported"><i class="icon fa fa-flag"></i><%- gettext("Reported") %></span> <span class="post-label-closed"><i class="icon fa fa-lock"></i><%- gettext("Closed") %></span> </div> </div> <div class="post-header-actions post-extended-content"> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'post', primaryActions: ['vote', 'follow'], secondaryActions: ['pin', 'edit', 'delete', 'report', 'close'] } ) %> </div> </header> <div class="post-body"><%- body %></div> <% if (mode == "tab" && obj.courseware_url) { %> <% var courseware_title_linked = interpolate( '<a href="%(courseware_url)s">%(courseware_title)s</a>', {courseware_url: courseware_url, courseware_title: _.escape(courseware_title)}, true ); %> <div class="post-context"> <%= interpolate( _.escape(gettext('Related to: %(courseware_title_linked)s')), {courseware_title_linked: courseware_title_linked}, true ) %> </div> <% } %> </div> </script> <script aria-hidden="true" type="text/template" id="thread-edit-template"> <h1>Editing post</h1> <ul class="post-errors"></ul> <div class="forum-edit-post-form-wrapper"></div> <div class="form-row"> <label class="sr" for="edit-post-title">Edit post title</label> <input type="text" id="edit-post-title" class="edit-post-title" name="title" value="<%-title %>" placeholder="Title"> </div> <div class="form-row"> <div class="edit-post-body" name="body"><%- body %></div> </div> <input type="submit" id="edit-post-submit" class="post-update" value="Update post"> <a href="#" class="post-cancel">Cancel</a> </script> <script aria-hidden="true" type="text/template" id="thread-response-template"> <div class="discussion-response"></div> <a href="#" class="action-show-comments"> <%- interpolate('Show Comments (%(num_comments)s)', {num_comments: comments.length}, true) %> <i class="icon fa fa-caret-down"></i> </a> <ol class="comments"> <li class="new-comment"> <form class="comment-form" data-id="<%- wmdId %>"> <ul class="discussion-errors"></ul> <label class="sr" for="add-new-comment">Add a comment</label> <div class="comment-body" id="add-new-comment" data-id="<%- wmdId %>" data-placeholder="Add a comment"></div> <div class="comment-post-control"> <a class="discussion-submit-comment control-button" href="#">Submit</a> </div> </form> </li> </ol> </script> <script aria-hidden="true" type="text/template" id="thread-response-show-template"> <header> <div class="response-header-content"> <%= author_display %> <p class="posted-details"> <span class="timeago" title="<%= created_at %>"><%= created_at %></span> <% if (obj.endorsement) { %> - <%= interpolate( thread.get("thread_type") == "question" ? (endorsement.username ? "marked as answer %(time_ago)s by %(user)s" : "marked as answer %(time_ago)s") : (endorsement.username ? "endorsed %(time_ago)s by %(user)s" : "endorsed %(time_ago)s"), { 'time_ago': '<span class="timeago" title="' + endorsement.time + '">' + endorsement.time + '</span>', 'user': endorser_display }, true )%><% } %> </p> <div class="post-labels"> <span class="post-label-reported"><i class="icon fa fa-flag"></i>Reported</span> </div> </div> <div class="response-header-actions"> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'response', primaryActions: ['vote', thread.get('thread_type') == 'question' ? 'answer' : 'endorse'], secondaryActions: ['edit', 'delete', 'report'] } ) %> </div> </header> <div class="response-body"><%- body %></div> </script> <script aria-hidden="true" type="text/template" id="thread-response-edit-template"> <div class="edit-post-form"> <h1>Editing response</h1> <ul class="edit-post-form-errors"></ul> <div class="form-row"> <div class="edit-post-body" name="body" data-id="<%- id %>"><%- body %></div> </div> <input type="submit" id="edit-response-submit"class="post-update" value="Update response"> <a href="#" class="post-cancel">Cancel</a> </div> </script> <script aria-hidden="true" type="text/template" id="response-comment-show-template"> <div id="comment_<%- id %>"> <div class="response-body"><%- body %></div> <%= _.template( $('#forum-actions').html(), { contentId: cid, contentType: 'comment', primaryActions: [], secondaryActions: ['edit', 'delete', 'report'] } ) %> <p class="posted-details"> <%= interpolate( 'posted %(time_ago)s by %(author)s', {'time_ago': '<span class="timeago" title="' + created_at + '">' + created_at + '</span>', 'author': author_display}, true )%> </p> <div class="post-labels"> <span class="post-label-reported"><i class="icon fa fa-flag"></i>Reported</span> </div> </div> </script> <script aria-hidden="true" type="text/template" id="response-comment-edit-template"> <div class="edit-post-form" id="comment_<%- id %>"> <h1>Editing comment</h1> <ul class="edit-comment-form-errors"></ul> <div class="form-row"> <div class="edit-comment-body" name="body" data-id="<%- id %>"><%- body %></div> </div> <input type="submit" id="edit-comment-submit" class="post-update" value="Update comment"> <a href="#" class="post-cancel">Cancel</a> </div> </script> <script aria-hidden="true" type="text/template" id="thread-list-item-template"> <li data-id="<%- id %>" class="forum-nav-thread<% if (typeof(read) != "undefined" && !read) { %> is-unread<% } %>"> <a href="#" class="forum-nav-thread-link"> <div class="forum-nav-thread-wrapper-0"> <% var icon_class, sr_text; if (thread_type == "discussion") { icon_class = "fa-comments"; sr_text = "discussion"; } else if (endorsed) { icon_class = "fa-check-square-o"; sr_text = "answered question"; } else { icon_class = "fa-question"; sr_text = "unanswered question"; } %> <span class="sr"><%= sr_text %></span> <i class="icon fa <%= icon_class %>"></i> </div><div class="forum-nav-thread-wrapper-1"> <span class="forum-nav-thread-title"><%- title %></span> <% var labels = ""; if (pinned) { labels += '<li class="post-label-pinned"><i class="icon fa fa-thumb-tack"></i>Pinned</li> '; } if (typeof(subscribed) != "undefined" && subscribed) { labels += '<li class="post-label-following"><i class="icon fa fa-star"></i>Following</li> '; } if (staff_authored) { labels += '<li class="post-label-by-staff"><i class="icon fa fa-user"></i>By: Staff</li> '; } if (community_ta_authored) { labels += '<li class="post-label-by-community-ta"><i class="icon fa fa-user"></i>By: Community TA</li> '; } if (labels != "") { print('<ul class="forum-nav-thread-labels">' + labels + '</ul>'); } %> </div><div class="forum-nav-thread-wrapper-2"> <span class="forum-nav-thread-votes-count">+<%= interpolate( '%(votes_up_count)s%(span_sr_open)s votes %(span_close)s', {'span_sr_open': '<span class="sr">', 'span_close': '</span>', 'votes_up_count': votes['up_count']}, true ) %></span> <span class="forum-nav-thread-comments-count <% if (unread_comments_count > 0) { %>is-unread<% } %>"> <% var fmt; // Counts in data do not include the post itself, but the UI should var data = { 'span_sr_open': '<span class="sr">', 'span_close': '</span>', 'unread_comments_count': unread_comments_count + (read ? 0 : 1), 'comments_count': comments_count + 1 }; if (unread_comments_count > 0) { fmt = '%(comments_count)s %(span_sr_open)scomments (%(unread_comments_count)s unread comments)%(span_close)s'; } else { fmt = '%(comments_count)s %(span_sr_open)scomments %(span_close)s'; } print(interpolate(fmt, data, true)); %> </span> </div> </a> </li> </script> <script aria-hidden="true" type="text/template" id="discussion-home"> <div class="discussion-article blank-slate"> <section class="home-header"> <span class="label">DISCUSSION HOME:</span> <h1 class="home-title">Paradox and Infinity</h1> </section> <span class="label label-settings"> How to use edX discussions </span> <table class="home-helpgrid"> <tr class="helpgrid-row helpgrid-row-navigation"> <td class="row-title">Find discussions</td> <td class="row-item"> <i class="icon fa fa-reorder"></i> <span class="row-description">Focus in on specific topics</span> </td> <td class="row-item"> <i class="icon fa fa-search"></i> <span class="row-description">Search for specific posts </span> </td> <td class="row-item"> <i class="icon fa fa-sort"></i> <span class="row-description">Sort by date, vote, or comments</span> </td> </tr> <tr class="helpgrid-row helpgrid-row-participation"> <td class="row-title">Engage with posts</td> <td class="row-item"> <i class="icon fa fa-plus"></i> <span class="row-description">Upvote posts and good responses</span> </td> <td class="row-item"> <i class="icon fa fa-flag"></i> <span class="row-description">Report Forum Misuse</span> </td> <td class="row-item"> <i class="icon fa fa-star"></i> <span class="row-description">Follow posts for updates</span> </td> </tr> <tr class="helpgrid-row helpgrid-row-notification"> <td class="row-title">Receive updates</td> <td class="row-item-full" colspan="3"> <label for="email-setting-checkbox"> <span class="sr">Toggle Notifications Setting</span> <span class="notification-checkbox"> <input type="checkbox" id="email-setting-checkbox" class="email-setting" name="email-notification"/> <i class="icon fa fa-envelope"></i> </span> </label> <span class="row-description">Check this box to receive an email digest once a day notifying you about new, unread activity from posts you are following.</span> </td> </tr> </table> </div> </script> <script aria-hidden="true" type="text/template" id="search-alert-template"> <div class="search-alert" id="search-alert-<%- cid %>"> <div class="search-alert-content"> <p class="message"><%= message %></p> </div> <div class="search-alert-controls"> <a href="#" class="dismiss control control-dismiss"><i class="icon fa fa-remove"></i></a> </div> </div> </script> <script aria-hidden="true" type="text/template" id="new-post-template"> <form class="forum-new-post-form"> <ul class="post-errors" style="display: none"></ul> <div class="forum-new-post-form-wrapper"></div> <% if (cohort_options) { %> <div class="post-field group-selector-wrapper<% if (!is_commentable_cohorted) { %> disabled<% } %>" > <label class="field-label"> <span class="field-label-text"> Visible To: </span><select aria-describedby="field_help_visible_to" class="field-input js-group-select" name="group_id" <% if (!is_commentable_cohorted) { %>disabled<% } %>> <option value="">All Groups</option> <% _.each(cohort_options, function(opt) { %> <option value="<%= opt.value %>" <% if (opt.selected) { %>selected<% } %>><%- opt.text %></option> <% }); %> </select> </label><div class="field-help" id="field_help_visible_to"> Discussion admins, moderators, and TAs can make their posts visible to all students or specify a single cohort. </div> </div> <% } %> <div class="post-field"> <label class="field-label"> <span class="sr">Title:</span> <input aria-describedby="field_help_title" type="text" class="field-input js-post-title" name="title" placeholder="Title"> </label><span class="field-help" id="field_help_title"> Add a clear and descriptive title to encourage participation. </span> </div> <div class="post-field js-post-body editor" name="body" data-placeholder="Enter your question or comment"></div> <div class="post-options"> <label class="post-option is-enabled"> <input type="checkbox" name="follow" class="post-option-input js-follow" checked> <i class="icon fa fa-star"></i>follow this post </label> <% if (allow_anonymous) { %> <label class="post-option"> <input type="checkbox" name="anonymous" class="post-option-input js-anon"> post anonymously </label> <% } %> <% if (allow_anonymous_to_peers) { %> <label class="post-option"> <input type="checkbox" name="anonymous_to_peers" class="post-option-input js-anon-peers"> post anonymously to classmates </label> <% } %> </div> <div> <input type="submit" class="submit" value="Add Post"> <a href="#" class="cancel">Cancel</a> </div> </form> </script> <script aria-hidden="true" type="text/template" id="thread-type-template"> <div class="post-field"> <div class="field-label"> <span class="field-label-text"> Post type: </span><fieldset class="field-input"><legend class="sr">Post type:</legend> <input aria-describedby="field_help_post_type" type="radio" name="<%= form_id %>-post-type" class="post-type-input" id="<%= form_id %>-post-type-question" value="question"> <label for="<%= form_id %>-post-type-question" class="post-type-label"> <i class="icon fa fa-question"></i> Question </label> <input aria-describedby="field_help_post_type" type="radio" name="<%= form_id %>-post-type" class="post-type-input" id="<%= form_id %>-post-type-discussion" value="discussion" checked> <label for="<%= form_id %>-post-type-discussion" class="post-type-label"> <i class="icon fa fa-comments"></i> Discussion </label> </fieldset> </div><span class="field-help" id="field_help_post_type"> Questions raise issues that need answers. Discussions share ideas and start conversations. </span> </div> </script> <script aria-hidden="true" type="text/template" id="new-post-menu-entry-template"> <li role="menuitem" class="topic-menu-item"> <a href="#" class="topic-title" data-discussion-id="<%- id %>" data-cohorted="<%- is_cohorted %>"><%- text %></a> </li> </script> <script aria-hidden="true" type="text/template" id="new-post-menu-category-template"> <li role="menuitem" class="topic-menu-item"> <span class="topic-title"><%- text %></span> <ul role="menu" class="topic-submenu"><%= entries %></ul> </li> </script> <script aria-hidden="true" type="text/template" id="topic-template"> <div class="field-label"> <span class="field-label-text">Topic Area:</span><div class="field-input post-topic"> <a href="#" class="post-topic-button"> <span class="sr">Discussion topics; current selection is: </span> <span class="js-selected-topic"></span> <span class="drop-arrow" aria-hidden="true">▾</span> </a> <div class="topic-menu-wrapper"> <label class="topic-filter-label"> <span class="sr">Filter topics</span> <input aria-describedby="field_help_topic_area" type="text" class="topic-filter-input" placeholder="Filter topics"> </label> <ul class="topic-menu" role="menu"><%= topics_html %></ul> </div> </div> </div><span class="field-help" id="field_help_topic_area"> Add your post to a relevant topic to help others find it. </span> </script> <script type="text/template" id="forum-action-endorse"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-endorse" role="checkbox" aria-checked="false"> <span class="sr">Endorse</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Endorse</span> <span class="label-checked">Unendorse</span> </span> <span class="action-icon"><i class="icon fa fa-check"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-answer"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-answer" role="checkbox" aria-checked="false"> <span class="sr">Mark as Answer</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Mark as Answer</span> <span class="label-checked">Unmark as Answer</span> </span> <span class="action-icon"><i class="icon fa fa-check"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-follow"> <li class="actions-item"> <a href="javascript:void(0)" class="action-button action-follow" role="checkbox" aria-checked="false"> <span class="sr">Follow</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Follow</span> <span class="label-checked">Unfollow</span> </span> <span class="action-icon"><i class="icon fa fa-star"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-vote"> <li class="actions-item"> <span aria-hidden="true" class="display-vote" > <span class="vote-count"></span> </span> <a href="#" class="action-button action-vote" role="checkbox" aria-checked="false"> <span class="sr">Vote for this post,&nbsp;</span> <span class="sr js-sr-vote-count"></span> <span class="action-label" aria-hidden="true"> <span class="vote-count"></span> </span> <span class="action-icon" aria-hidden="true"> <i class="icon fa fa-plus"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-report"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-report" role="checkbox" aria-checked="false"> <span class="sr">Report abuse</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Report</span> <span class="label-checked">Unreport</span> </span> <span class="action-icon"> <i class="icon fa fa-flag"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-pin"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-pin" role="checkbox" aria-checked="false"> <span class="sr">Pin</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Pin</span> <span class="label-checked">Unpin</span> </span> <span class="action-icon"> <i class="icon fa fa-thumb-tack"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-close"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-close" role="checkbox" aria-checked="false"> <span class="sr">Close</span> <span class="action-label" aria-hidden="true"> <span class="label-unchecked">Close</span> <span class="label-checked">Open</span> </span> <span class="action-icon"> <i class="icon fa fa-lock"></i> </span> </a> </li> </script> <script type="text/template" id="forum-action-edit"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-edit" role="button"> <span class="action-label">Edit</span> <span class="action-icon"><i class="icon fa fa-pencil"></i></span> </a> </li> </script> <script type="text/template" id="forum-action-delete"> <li class="actions-item"> <a href="javascript:void(0)" class="action-list-item action-delete" role="button"> <span class="action-label">Delete</span> <span class="action-icon"><i class="icon fa fa-remove"></i></span> </a> </li> </script> <script type="text/template" id="forum-actions"> <ul class="<%= contentType %>-actions-list"> <% _.each(primaryActions, function(action) { print(_.template($('#forum-action-' + action).html(), {})) }) %> <li class="actions-item is-visible"> <div class="more-wrapper"> <a href="javascript:void(0)" class="action-button action-more" role="button" aria-haspopup="true" aria-controls="action-menu-<%= contentId %>"> <span class="action-label">More</span> <span class="action-icon"><i class="icon fa fa-ellipsis-h"></i></span> </a> <div class="actions-dropdown" id="action-menu-<%= contentType %>" aria-expanded="false"> <ul class="actions-dropdown-list"> <% _.each(secondaryActions, function(action) { print(_.template($('#forum-action-' + action).html(), {})) }) %> </ul> </div> </div> </li> </ul> </script> <script aria-hidden="true" type="text/template" id="post-user-display-template"> <% if (username) { %> <a href="<%- user_url %>" class="username"><%- username %></a> <% if (is_community_ta) { %> <span class="user-label-community-ta">Community TA</span> <% } else if (is_staff) { %> <span class="user-label-staff">Staff</span> <% } %> <% } else { %> anonymous <% } %> </script> <div class="discussion-module" data-discussion-id="6ee7d5fc10d1d220c66ddb1b62d324a0ee3a46b4"> <a class="discussion-show control-button" href="javascript:void(0)" data-discussion-id="6ee7d5fc10d1d220c66ddb1b62d324a0ee3a46b4" role="button"><span class="show-hide-discussion-icon"></span><span class="button-text">Show Discussion</span></a> <a href="#" class="new-post-btn" role="button"><span class="icon fa fa-edit new-post-icon"></span>New Post</a> </div> </div> </div> </div> </div>
© All Rights Reserved

open